@@ -60,18 +60,18 @@ using namespace KMyMoneyRegister;
 using namespace KMyMoneyTransactionForm;
 using namespace Invest;
 
-class InvestTransactionEditorPrivate {
+class InvestTransactionEditor::Private {
   friend class Invest::Activity;
 
 public:
-  InvestTransactionEditorPrivate(InvestTransactionEditor* parent) :
+  Private(InvestTransactionEditor* parent) :
     m_parent(parent),
     m_activity(0)
   {
-    m_phonyAccount = MyMoneyAccount(QCString("Phony-ID"), MyMoneyAccount());
+    m_phonyAccount = MyMoneyAccount("Phony-ID", MyMoneyAccount());
   }
 
-  ~InvestTransactionEditorPrivate() {
+  ~Private() {
     delete m_activity;
   }
 
@@ -85,7 +85,7 @@ public:
 
 
 InvestTransactionEditor::InvestTransactionEditor() :
-  d(new InvestTransactionEditorPrivate(this))
+  d(new Private(this))
 {
 }
 
@@ -96,7 +96,7 @@ InvestTransactionEditor::~InvestTransactionEditor()
 
 InvestTransactionEditor::InvestTransactionEditor(TransactionEditorContainer* regForm, KMyMoneyRegister::InvestTransaction* item, const KMyMoneyRegister::SelectedTransactions& list, const QDate& lastPostDate) :
   TransactionEditor(regForm, item, list, lastPostDate),
-  d(new InvestTransactionEditorPrivate(this))
+  d(new Private(this))
 {
   // dissect the transaction into its type, splits, currency, security etc.
   dissectTransaction(m_transaction, m_split,
@@ -198,13 +198,14 @@ void InvestTransactionEditor::createEditWidgets(void)
   connect(activity, SIGNAL(activitySelected(MyMoneySplit::investTransactionTypeE)), this, SLOT(slotUpdateButtonState()));
 
   m_editWidgets["postdate"] = new kMyMoneyDateInput;
+  connect(m_editWidgets["postdate"], SIGNAL(dateChanged(const QDate&)), this, SLOT(slotUpdateButtonState()));
 
   KMyMoneySecurity* security = new KMyMoneySecurity;
   security->setHint(i18n("Security"));
   m_editWidgets["security"] = security;
-  connect(security, SIGNAL(itemSelected(const QCString&)), this, SLOT(slotUpdateSecurity(const QCString&)));
+  connect(security, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateSecurity(const QString&)));
   connect(security, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
-  connect(security, SIGNAL(createItem(const QString&, QCString&)), this, SLOT(slotCreateSecurity(const QString&, QCString&)));
+  connect(security, SIGNAL(createItem(const QString&, QString&)), this, SLOT(slotCreateSecurity(const QString&, QString&)));
   connect(security, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
 
   KMyMoneyCategory* asset = new KMyMoneyCategory(0, 0, false);
@@ -216,20 +217,20 @@ void InvestTransactionEditor::createEditWidgets(void)
   KMyMoneyCategory* fees = new KMyMoneyCategory(0, 0, true);
   fees->setHint(i18n("Fees"));
   m_editWidgets["fee-account"] = fees;
-  connect(fees, SIGNAL(itemSelected(const QCString&)), this, SLOT(slotUpdateFeeCategory(const QCString&)));
+  connect(fees, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateFeeCategory(const QString&)));
   connect(fees, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
   connect(fees, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateFeeVisibility(const QString&)));
-  connect(fees, SIGNAL(createItem(const QString&, QCString&)), this, SLOT(slotCreateFeeCategory(const QString&, QCString&)));
+  connect(fees, SIGNAL(createItem(const QString&, QString&)), this, SLOT(slotCreateFeeCategory(const QString&, QString&)));
   connect(fees, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
   connect(fees->splitButton(), SIGNAL(clicked()), this, SLOT(slotEditFeeSplits()));
 
   KMyMoneyCategory* interest = new KMyMoneyCategory(0, 0, true);
   interest->setHint(i18n("Interest"));
   m_editWidgets["interest-account"] = interest;
-  connect(interest, SIGNAL(itemSelected(const QCString&)), this, SLOT(slotUpdateInterestCategory(const QCString&)));
+  connect(interest, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateInterestCategory(const QString&)));
   connect(interest, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
   connect(interest, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateInterestVisibility(const QString&)));
-  connect(interest, SIGNAL(createItem(const QString&, QCString&)), this, SLOT(slotCreateInterestCategory(const QString&, QCString&)));
+  connect(interest, SIGNAL(createItem(const QString&, QString&)), this, SLOT(slotCreateInterestCategory(const QString&, QString&)));
   connect(interest, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
   connect(interest->splitButton(), SIGNAL(clicked()), this, SLOT(slotEditInterestSplits()));
 
@@ -270,7 +271,7 @@ void InvestTransactionEditor::createEditWidgets(void)
 
   KMyMoneyReconcileCombo* reconcile = new KMyMoneyReconcileCombo;
   m_editWidgets["status"] = reconcile;
-  connect(reconcile, SIGNAL(itemSelected(const QCString&)), this, SLOT(slotUpdateButtonState()));
+  connect(reconcile, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateButtonState()));
 
   KMyMoneyRegister::QWidgetContainer::iterator it_w;
   for(it_w = m_editWidgets.begin(); it_w != m_editWidgets.end(); ++it_w) {
@@ -393,7 +394,7 @@ int InvestTransactionEditor::editSplits(const QString& categoryWidgetName, const
         if(isIncome)
           fees = -fees;
 
-        QCString categoryId;
+        QString categoryId;
         setupCategoryWidget(category, splits, categoryId, slotEditSplits);
         amount->setValue(fees);
         slotUpdateTotalAmount();
@@ -432,7 +433,7 @@ bool InvestTransactionEditor::createPseudoTransaction(MyMoneyTransaction& t, con
   return true;
 }
 
-void InvestTransactionEditor::slotCreateSecurity(const QString& name, QCString& id)
+void InvestTransactionEditor::slotCreateSecurity(const QString& name, QString& id)
 {
   MyMoneyAccount acc;
   QRegExp exp("([^:]+)");
@@ -443,10 +444,14 @@ void InvestTransactionEditor::slotCreateSecurity(const QString& name, QCString&
 
     // return id
     id = acc.id();
+
+    if(!id.isEmpty()) {
+      slotUpdateSecurity(id);
+    }
   }
 }
 
-void InvestTransactionEditor::slotCreateFeeCategory(const QString& name, QCString& id)
+void InvestTransactionEditor::slotCreateFeeCategory(const QString& name, QString& id)
 {
   MyMoneyAccount acc;
   acc.setName(name);
@@ -457,7 +462,7 @@ void InvestTransactionEditor::slotCreateFeeCategory(const QString& name, QCStrin
   id = acc.id();
 }
 
-void InvestTransactionEditor::slotUpdateFeeCategory(const QCString& id)
+void InvestTransactionEditor::slotUpdateFeeCategory(const QString& id)
 {
   haveWidget("fee-amount")->setDisabled(id.isEmpty());
 }
@@ -470,7 +475,7 @@ void InvestTransactionEditor::slotUpdateFeeVisibility(const QString& txt)
     w->setShown(haveWidget("fee-amount")->isVisible());
 }
 
-void InvestTransactionEditor::slotUpdateInterestCategory(const QCString& id)
+void InvestTransactionEditor::slotUpdateInterestCategory(const QString& id)
 {
   haveWidget("interest-amount")->setDisabled(id.isEmpty());
 }
@@ -496,7 +501,7 @@ void InvestTransactionEditor::slotUpdateInterestVisibility(const QString& txt)
     w->setShown(haveWidget("interest-amount")->isVisible());
 }
 
-void InvestTransactionEditor::slotCreateInterestCategory(const QString& name, QCString& id)
+void InvestTransactionEditor::slotCreateInterestCategory(const QString& name, QString& id)
 {
   MyMoneyAccount acc;
   acc.setName(name);
@@ -514,7 +519,7 @@ void InvestTransactionEditor::slotReloadEditWidgets(void)
   KMyMoneySecurity* security = dynamic_cast<KMyMoneySecurity*>(haveWidget("security"));
 
   AccountSet aSet;
-  QCString id;
+  QString id;
 
   // interest-account
   aSet.clear();
@@ -535,7 +540,7 @@ void InvestTransactionEditor::slotReloadEditWidgets(void)
 
 void InvestTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action /* action */)
 {
-  QCString id;
+  QString id;
 
   kMyMoneyDateInput* postDate = dynamic_cast<kMyMoneyDateInput*>(haveWidget("postdate"));
   KMyMoneyReconcileCombo* reconcile = dynamic_cast<KMyMoneyReconcileCombo*>(haveWidget("status"));
@@ -583,9 +588,11 @@ void InvestTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action /* action
     else
       postDate->setDate(QDate::currentDate());
 
-    // security
-    security->completion()->setSelected(m_split.accountId());
-    security->slotItemSelected(m_split.accountId());
+    // security (but only if it's not the investment account)
+    if(m_split.accountId() != m_account.id()) {
+      security->completion()->setSelected(m_split.accountId());
+      security->slotItemSelected(m_split.accountId());
+    }
 
     // activity
     activity->setActivity(d->m_activity->type());
@@ -655,7 +662,7 @@ void InvestTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action /* action
     // scan the list of selected transactions and check that they have
     // the same activity.
     KMyMoneyRegister::SelectedTransactions::iterator it_t = m_transactions.begin();
-    const QCString& action = m_item->split().action();
+    const QString& action = m_item->split().action();
     bool isNegative = m_item->split().shares().isNegative();
     bool allSameActivity = true;
     for(it_t = m_transactions.begin(); allSameActivity && (it_t != m_transactions.end()); ++it_t) {
@@ -704,7 +711,7 @@ MyMoneyMoney InvestTransactionEditor::subtotal(const QValueList<MyMoneySplit>& s
   return sum;
 }
 
-void InvestTransactionEditor::slotUpdateSecurity(const QCString& stockId)
+void InvestTransactionEditor::slotUpdateSecurity(const QString& stockId)
 {
   MyMoneyFile* file = MyMoneyFile::instance();
   MyMoneyAccount stock = file->account(stockId);
@@ -713,8 +720,12 @@ void InvestTransactionEditor::slotUpdateSecurity(const QCString& stockId)
   bool currencyKnown = !m_currency.id().isEmpty();
   if(!currencyKnown) {
     m_currency.setTradingSymbol("???");
-  } else if(typeid(*(d->m_activity)) != typeid(Invest::Split(this))) {
-    dynamic_cast<kMyMoneyEdit*>(haveWidget("shares"))->setPrecision(MyMoneyMoney::denomToPrec(m_security.smallestAccountFraction()));
+  } else {
+    if(typeid(*(d->m_activity)) != typeid(Invest::Split(this))) {
+      dynamic_cast<kMyMoneyEdit*>(haveWidget("shares"))->setPrecision(MyMoneyMoney::denomToPrec(m_security.smallestAccountFraction()));
+    } else {
+      dynamic_cast<kMyMoneyEdit*>(haveWidget("shares"))->setPrecision(-1);
+    }
   }
 
   updatePriceMode();
@@ -832,7 +843,7 @@ InvestTransactionEditor::priceModeE InvestTransactionEditor::priceMode(void) con
 {
   priceModeE mode = static_cast<priceModeE>(0);
   KMyMoneySecurity* sec = dynamic_cast<KMyMoneySecurity*>(m_editWidgets["security"]);
-  QCString accId;
+  QString accId;
   if(!sec->currentText().isEmpty()) {
     accId = sec->selectedItem();
     if(accId.isEmpty())
@@ -860,8 +871,8 @@ bool InvestTransactionEditor::setupPrice(const MyMoneyTransaction& t, MyMoneySpl
   int fract = acc.fraction();
 
   if(acc.currencyId() != t.commodity()) {
-    QMap<QCString, MyMoneyMoney>::Iterator it_p;
-    QCString key = t.commodity() + "-" + acc.currencyId();
+    QMap<QString, MyMoneyMoney>::Iterator it_p;
+    QString key = t.commodity() + "-" + acc.currencyId();
     it_p = m_priceInfo.find(key);
 
     // if it's not found, then collect it from the user first
@@ -911,17 +922,17 @@ bool InvestTransactionEditor::createTransaction(MyMoneyTransaction& t, const MyM
 
   KMyMoneySecurity* sec = dynamic_cast<KMyMoneySecurity*>(m_editWidgets["security"]);
   if(!isMultiSelection() || (isMultiSelection() && !sec->currentText().isEmpty())) {
-    QCString securityId = sec->selectedItem();
+    QString securityId = sec->selectedItem();
     if(!securityId.isEmpty()) {
       s0.setAccountId(securityId);
       MyMoneyAccount stockAccount = file->account(securityId);
-      QCString currencyId = stockAccount.currencyId();
+      QString currencyId = stockAccount.currencyId();
       MyMoneySecurity security = file->security(currencyId);
 
       t.setCommodity(security.tradingCurrency());
     } else {
-      qDebug("InvestTransactionEditor::createTransaction: no security selected!");
-      return false;
+      s0.setAccountId(m_account.id());
+      t.setCommodity(m_account.currencyId());
     }
   }
 
