@@ -60,7 +60,7 @@ class KMYMONEY_EXPORT MyMoneyReport: public MyMoneyObject, public MyMoneyTransac
 {
 public:
   // When adding a new row type, be sure to add a corresponding entry in kTypeArray
-  enum ERowType { eNoRows = 0, eAssetLiability, eExpenseIncome, eCategory, eTopCategory, eAccount, ePayee, eMonth, eWeek, eTopAccount, eAccountByTopAccount, eEquityType, eAccountType, eInstitution, eBudget, eBudgetActual, eSchedule, eAccountInfo, eAccountLoanInfo, eAccountReconcile};
+  enum ERowType { eNoRows = 0, eAssetLiability, eExpenseIncome, eCategory, eTopCategory, eAccount, ePayee, eMonth, eWeek, eTopAccount, eAccountByTopAccount, eEquityType, eAccountType, eInstitution, eBudget, eBudgetActual, eSchedule, eAccountInfo, eAccountLoanInfo, eAccountReconcile, eCashFlow};
   enum EReportType { eNoReport = 0, ePivotTable, eQueryTable, eInfoTable };
   enum EColumnType { eNoColumns = 0, eDays = 1, eMonths = 1, eBiMonths = 2, eQuarters = 3, eWeeks = 7, eYears = 12 };
 
@@ -80,8 +80,8 @@ public:
 
 public:
   MyMoneyReport(void);
-  MyMoneyReport(ERowType _rt, unsigned _ct, dateOptionE _dl, bool _ss, const QString& _name, const QString& _comment );
-  MyMoneyReport(const QCString& id, const MyMoneyReport& right);
+  MyMoneyReport(ERowType _rt, unsigned _ct, dateOptionE _dl, EDetailLevel _ss, const QString& _name, const QString& _comment );
+  MyMoneyReport(const QString& id, const MyMoneyReport& right);
 
   /**
     * This constructor creates an object based on the data found in the
@@ -92,7 +92,6 @@ public:
 
   // Simple get operations
   const QString& name(void) const { return m_name; }
-  bool isShowingSubAccounts(void) const { return (m_detailLevel==eDetailAll); }
   bool isShowingRowTotals(void) const { return (m_showRowTotals); }
   EReportType reportType(void) const { return m_reportType; }
   ERowType rowType(void) const { return m_rowType; }
@@ -113,18 +112,22 @@ public:
   bool isChartDataLabels(void) const { return m_chartDataLabels; }
   bool isChartGridLines(void) const { return m_chartGridLines; }
   bool isChartByDefault(void) const { return m_chartByDefault; }
+  uint chartLineWidth(void) const { return m_chartLineWidth; }
   bool isIncludingSchedules(void) const { return m_includeSchedules; }
   bool isColumnsAreDays(void) const { return m_columnsAreDays; }
   bool isIncludingTransfers(void) const { return m_includeTransfers; }
   bool isIncludingUnusedAccounts(void) const { return m_includeUnusedAccounts; }
   bool hasBudget(void) const { return !m_budgetId.isEmpty(); }
-  const QCString& budget(void) const { return m_budgetId; }
+  const QString& budget(void) const { return m_budgetId; }
   bool isIncludingBudgetActuals(void) const { return m_includeBudgetActuals; }
   bool isIncludingForecast(void) const { return m_includeForecast; }
+  bool isIncludingMovingAverage(void) const { return m_includeMovingAverage; }
+  int movingAverageDays(void) const { return m_movingAverageDays; }
+  bool isIncludingPrice(void) const { return m_includePrice; }
+  bool isIncludingAveragePrice(void) const { return m_includeAveragePrice; }
 
   // Simple set operations
   void setName(const QString& _s) { m_name = _s; }
-  void setShowSubAccounts(bool _f) { m_detailLevel = _f?eDetailAll:eDetailTop; }
   void setConvertCurrency(bool _f) { m_convertCurrency = _f; }
   void setRowType(ERowType _rt);
   void setColumnType(EColumnType _ct) { m_columnType = _ct; }
@@ -140,12 +143,18 @@ public:
   void setChartDataLabels ( bool _f ) { m_chartDataLabels = _f; }
   void setChartGridLines ( bool _f ) { m_chartGridLines = _f; }
   void setChartByDefault ( bool _f ) { m_chartByDefault = _f; }
+  void setChartLineWidth ( uint _f ) { m_chartLineWidth = _f; }
   void setIncludingSchedules( bool _f ) { m_includeSchedules = _f; }
   void setColumnsAreDays( bool _f ) { m_columnsAreDays = _f; }
   void setIncludingTransfers( bool _f ) { m_includeTransfers = _f; }
   void setIncludingUnusedAccounts( bool _f ) { m_includeUnusedAccounts = _f; }
   void setShowingRowTotals( bool _f ) { m_showRowTotals = _f; }
+  void setIncludingBudgetActuals( bool _f ) { m_includeBudgetActuals = _f; }
   void setIncludingForecast( bool _f ) { m_includeForecast = _f; }
+  void setIncludingMovingAverage( bool _f ) { m_includeMovingAverage = _f; }
+  void setMovingAverageDays( int _days ) { m_movingAverageDays = _days; }
+  void setIncludingPrice( bool _f ) { m_includePrice = _f; }
+  void setIncludingAveragePrice( bool _f ) { m_includeAveragePrice = _f; }
 
   /**
     * Sets the budget used for this report
@@ -158,7 +167,7 @@ public:
     * simply checked for any non-empty string, and if so, hasBudget()
     * will return true.
     */
-  void setBudget( const QCString& _budget, bool _fa = true ) { m_budgetId = _budget; m_includeBudgetActuals=_fa; }
+  void setBudget( const QString& _budget, bool _fa = true ) { m_budgetId = _budget; m_includeBudgetActuals=_fa; }
 
   /**
     * This method allows you to clear the underlying transaction filter
@@ -321,7 +330,7 @@ public:
     * @retval true This object references object with id @p id.
     * @retval false This object does not reference the object with id @p id.
     */
-  virtual bool hasReferenceTo(const QCString& id) const;
+  virtual bool hasReferenceTo(const QString& id) const;
 
 private:
   /**
@@ -429,6 +438,10 @@ private:
     * should be shown as a textual report)
     */
   bool m_chartByDefault;
+  /**
+   * Width of the chart lines
+   */
+  uint m_chartLineWidth;
   /**
     * Whether to include scheduled transactions
     */
@@ -440,7 +453,7 @@ private:
   /**
     * The id of the budget associated with this report.
     */
-  QCString m_budgetId;
+  QString m_budgetId;
   /**
     * Whether this report should print the actual data to go along with
     * the budget.  This is only valid if the report has a budget.
@@ -459,6 +472,24 @@ private:
    * Whether this report should include forecast balance
    */
   bool m_includeForecast;
+  /**
+   * Whether this report should include moving average
+   */
+  bool m_includeMovingAverage;
+  /**
+   * The amount of days that spans each moving average
+   */
+  int m_movingAverageDays;
+  /**
+   * Whether this report should include prices
+   */
+  bool m_includePrice;
+  /**
+   * Whether this report should include moving average prices
+   */
+  bool m_includeAveragePrice;
+
+
 
 };
 
