@@ -37,13 +37,15 @@ MyMoneyTransactionFilter::MyMoneyTransactionFilter()
   m_filterSet.allFilter = 0;
   m_reportAllSplits = true;
   m_considerCategory = true;
+  m_invertText = false;
 }
 
-MyMoneyTransactionFilter::MyMoneyTransactionFilter(const QCString& id)
+MyMoneyTransactionFilter::MyMoneyTransactionFilter(const QString& id)
 {
   m_filterSet.allFilter = 0;
   m_reportAllSplits = false;
   m_considerCategory = false;
+  m_invertText = false;
 
   addAccount(id);
   // addCategory(id);
@@ -52,9 +54,11 @@ MyMoneyTransactionFilter::MyMoneyTransactionFilter(const QCString& id)
 MyMoneyTransactionFilter::~MyMoneyTransactionFilter()
 {
 }
+
 void MyMoneyTransactionFilter::clear(void)
 {
   m_filterSet.allFilter = 0;
+  m_invertText = false;
   m_accounts.clear();
   m_categories.clear();
   m_payees.clear();
@@ -72,22 +76,23 @@ void MyMoneyTransactionFilter::clearAccountFilter(void)
   m_accounts.clear();
 }
 
-void MyMoneyTransactionFilter::setTextFilter(const QRegExp& text)
+void MyMoneyTransactionFilter::setTextFilter(const QRegExp& text, bool invert)
 {
   m_filterSet.singleFilter.textFilter = 1;
+  m_invertText = invert;
   m_text = text;
 }
 
-void MyMoneyTransactionFilter::addAccount(const QCStringList& ids)
+void MyMoneyTransactionFilter::addAccount(const QStringList& ids)
 {
-  QCStringList::ConstIterator it;
+  QStringList::ConstIterator it;
 
   m_filterSet.singleFilter.accountFilter = 1;
   for(it = ids.begin(); it != ids.end(); ++it)
     addAccount(*it);
 }
 
-void MyMoneyTransactionFilter::addAccount(const QCString& id)
+void MyMoneyTransactionFilter::addAccount(const QString& id)
 {
   if(!m_accounts.isEmpty() && !id.isEmpty()) {
     if(m_accounts.find(id) != 0)
@@ -101,16 +106,16 @@ void MyMoneyTransactionFilter::addAccount(const QCString& id)
     m_accounts.insert(id, "");
 }
 
-void MyMoneyTransactionFilter::addCategory(const QCStringList& ids)
+void MyMoneyTransactionFilter::addCategory(const QStringList& ids)
 {
-  QCStringList::ConstIterator it;
+  QStringList::ConstIterator it;
 
   m_filterSet.singleFilter.categoryFilter = 1;
   for(it = ids.begin(); it != ids.end(); ++it)
     addCategory(*it);
 }
 
-void MyMoneyTransactionFilter::addCategory(const QCString& id)
+void MyMoneyTransactionFilter::addCategory(const QString& id)
 {
   if(!m_categories.isEmpty() && !id.isEmpty()) {
     if(m_categories.find(id) != 0)
@@ -145,7 +150,7 @@ void MyMoneyTransactionFilter::setAmountFilter(const MyMoneyMoney& from, const M
   }
 }
 
-void MyMoneyTransactionFilter::addPayee(const QCString& id)
+void MyMoneyTransactionFilter::addPayee(const QString& id)
 {
   if(!m_payees.isEmpty() && !id.isEmpty()) {
     if(m_payees.find(id) != 0)
@@ -217,42 +222,47 @@ const QValueList<MyMoneySplit>& MyMoneyTransactionFilter::matchingSplits(void) c
   return m_matchingSplits;
 }
 
-bool MyMoneyTransactionFilter::match(const MyMoneySplit * const sp) const
+bool MyMoneyTransactionFilter::matchText(const MyMoneySplit * const sp) const
 {
-  bool rc = true;
-  MyMoneyFile* file = MyMoneyFile::instance();
-
   // check if the text is contained in one of the fields
   // memo, value, number, payee, account, date
   if(m_filterSet.singleFilter.textFilter) {
-    bool textMatch = false;
+    MyMoneyFile* file = MyMoneyFile::instance();
     const MyMoneyAccount& acc = file->account(sp->accountId());
     const MyMoneySecurity& sec = file->security(acc.currencyId());
     if(sp->memo().contains(m_text)
+    || sp->shares().formatMoney(acc.fraction(sec)).contains(m_text)
     || sp->value().formatMoney(acc.fraction(sec)).contains(m_text)
     || sp->number().contains(m_text))
-      textMatch = true;
+      return !m_invertText;
 
-    if(!textMatch && acc.name().contains(m_text))
-      textMatch = true;
+    if(acc.name().contains(m_text))
+      return !m_invertText;
 
-    if(!textMatch && !sp->payeeId().isEmpty()) {
+    if(!sp->payeeId().isEmpty()) {
       const MyMoneyPayee& payee = file->payee(sp->payeeId());
       if(payee.name().contains(m_text))
-        textMatch = true;
+        return !m_invertText;
     }
-
-    if(!textMatch)
-      rc = false;
+    return m_invertText;
   }
+  return true;
+}
 
-  if(rc && m_filterSet.singleFilter.amountFilter) {
+bool MyMoneyTransactionFilter::matchAmount(const MyMoneySplit * const sp) const
+{
+  if(m_filterSet.singleFilter.amountFilter) {
     if(((sp->value().abs() < m_fromAmount) || sp->value().abs() > m_toAmount)
     && ((sp->shares().abs() < m_fromAmount) || sp->shares().abs() > m_toAmount))
-      rc = false;
+      return false;
   }
 
-  return rc;
+  return true;
+}
+
+bool MyMoneyTransactionFilter::match(const MyMoneySplit * const sp) const
+{
+  return matchText(sp) && matchAmount(sp);
 }
 
 bool MyMoneyTransactionFilter::match(const MyMoneyTransaction& transaction)
@@ -391,7 +401,8 @@ bool MyMoneyTransactionFilter::match(const MyMoneyTransaction& transaction)
   // check if we still have something to do
   if(filterSet.allFilter != 0) {
     for(sp = matchingSplits.first(); sp != 0;) {
-      MyMoneySplit* removeSplit = match(sp) ? 0 : sp;
+      MyMoneySplit* removeSplit = 0;
+      removeSplit = (matchAmount(sp) && matchText(sp)) ? 0 : sp;
 
       const MyMoneyAccount& acc = file->account(sp->accountId());
 
@@ -405,50 +416,6 @@ bool MyMoneyTransactionFilter::match(const MyMoneyTransaction& transaction)
           break;
       }
 
-#if 0
-      // TODO code moved to match() and should be removed here
-      const MyMoneyAccount& acc = storage->account(sp->accountId());
-
-      // Determine if this account is a category or an account
-      bool isCategory = false;
-      switch(acc.accountGroup()) {
-        case MyMoneyAccount::Income:
-        case MyMoneyAccount::Expense:
-          isCategory = true;
-        default:
-          break;
-      }
-
-      // check if the text is contained in one of the fields
-      // memo, value, number, payee, account, date
-      if(m_filterSet.singleFilter.textFilter) {
-        bool textMatch = false;
-        if(sp->memo().contains(m_text)
-        || sp->value().formatMoney().contains(m_text)
-        || sp->number().contains(m_text))
-          textMatch = true;
-
-        if(!textMatch && acc.name().contains(m_text))
-          textMatch = true;
-
-        if(!textMatch && !sp->payeeId().isEmpty()) {
-          const MyMoneyPayee& payee = storage->payee(sp->payeeId());
-          if(payee.name().contains(m_text))
-            textMatch = true;
-        }
-
-        if(!textMatch)
-          removeSplit = sp;
-      }
-
-      if(!removeSplit && m_filterSet.singleFilter.amountFilter) {
-        if(sp->value().abs() < m_fromAmount)
-          removeSplit = sp;
-        if(sp->value().abs() > m_toAmount)
-          removeSplit = sp;
-      }
-#endif
-
       if(!isCategory && !removeSplit) {
         // check the payee list
         if(!removeSplit && m_filterSet.singleFilter.payeeFilter) {
@@ -545,7 +512,7 @@ int MyMoneyTransactionFilter::splitType(const MyMoneyTransaction& t, const MyMon
     return allTypes;
 
   if(t.splitCount() == 2) {
-    QCString ida, idb;
+    QString ida, idb;
     ida = t.splits()[0].accountId();
     idb = t.splits()[1].accountId();
 
@@ -575,17 +542,17 @@ MyMoneyTransactionFilter::validityOptionE MyMoneyTransactionFilter::validTransac
   return (val == MyMoneyMoney(0,1)) ? valid : invalid;
 }
 
-bool MyMoneyTransactionFilter::includesCategory( const QCString& cat ) const
+bool MyMoneyTransactionFilter::includesCategory( const QString& cat ) const
 {
   return (! m_filterSet.singleFilter.categoryFilter) || m_categories.find( cat );
 }
 
-bool MyMoneyTransactionFilter::includesAccount( const QCString& acc ) const
+bool MyMoneyTransactionFilter::includesAccount( const QString& acc ) const
 {
   return (! m_filterSet.singleFilter.accountFilter) || m_accounts.find( acc );
 }
 
-bool MyMoneyTransactionFilter::includesPayee( const QCString& pye ) const
+bool MyMoneyTransactionFilter::includesPayee( const QString& pye ) const
 {
   return (! m_filterSet.singleFilter.payeeFilter) || m_payees.find( pye );
 }
@@ -611,7 +578,7 @@ bool MyMoneyTransactionFilter::numberFilter( QString& from, QString& to ) const
   return m_filterSet.singleFilter.nrFilter==1;
 }
 
-bool MyMoneyTransactionFilter::payees(QCStringList& list) const
+bool MyMoneyTransactionFilter::payees(QStringList& list) const
 {
   bool result = m_filterSet.singleFilter.payeeFilter;
 
@@ -627,7 +594,7 @@ bool MyMoneyTransactionFilter::payees(QCStringList& list) const
   return result;
 }
 
-bool MyMoneyTransactionFilter::accounts(QCStringList& list) const
+bool MyMoneyTransactionFilter::accounts(QStringList& list) const
 {
   bool result = m_filterSet.singleFilter.accountFilter;
 
@@ -636,7 +603,7 @@ bool MyMoneyTransactionFilter::accounts(QCStringList& list) const
     QAsciiDictIterator<char> it_account( m_accounts );
     while ( it_account.current() )
     {
-      QCString account = it_account.currentKey();
+      QString account = it_account.currentKey();
       list += account;
       ++it_account;
     }
@@ -644,7 +611,7 @@ bool MyMoneyTransactionFilter::accounts(QCStringList& list) const
   return result;
 }
 
-bool MyMoneyTransactionFilter::categories(QCStringList& list) const
+bool MyMoneyTransactionFilter::categories(QStringList& list) const
 {
   bool result = m_filterSet.singleFilter.categoryFilter;
 
@@ -875,7 +842,7 @@ bool MyMoneyTransactionFilter::translateDateRange(dateOptionE id, QDate& start,
   return rc;
 }
 
-void MyMoneyTransactionFilter::removeReference(const QCString& id)
+void MyMoneyTransactionFilter::removeReference(const QString& id)
 {
   if(m_accounts.find(id)) {
     qDebug("%s", (QString("Remove account '%1' from report").arg(id)).data());
