@@ -56,7 +56,7 @@ class FilterFail {
         m_storage (storage)
     {}
 
-    inline bool operator() (const QPair<QCString, MyMoneyTransaction>& transactionPair)
+    inline bool operator() (const QPair<QString, MyMoneyTransaction>& transactionPair)
     { return (*this) (transactionPair.second); }
 
     inline bool operator() (const MyMoneyTransaction& transaction)
@@ -112,6 +112,7 @@ class MyMoneyDbDrivers {
       **/
     const QMap<QString, QString> driverMap() const {return (m_driverMap);};
     databaseTypeE driverToType (const QString& driver) const;
+    bool isTested (databaseTypeE dbType) const;
   private:
     QMap<QString, QString> m_driverMap;
 };
@@ -260,7 +261,7 @@ class MyMoneyDbIndex {
 
 /**
   * The MyMoneyDbTable class is a representation of a db table.
-  * It has a list of the columns (pointers to MyMoneyDbColumn types) and a 
+  * It has a list of the columns (pointers to MyMoneyDbColumn types) and a
   * list of any indices that may be on the table.
   * Additionally, a string for a parameterized query for each of some common
   * tasks on a table is created by the ctor.
@@ -293,7 +294,12 @@ class MyMoneyDbTable {
       * @return QString for the syntax to drop the primary key.
       */
     const QString dropPrimaryKeyString(databaseTypeE dbType) const;
-
+    /**
+      * This method returns a comma-separated list of all column names in the table
+      *
+      * @return QString column list.
+      */
+    const QString columnList() const;
     /**
       * This method returns the string for changing a column's definition.  It covers statements
       * like ALTER TABLE..CHANGE COLUMN, MODIFY COLUMN, etc.
@@ -372,7 +378,7 @@ class MyMoneyDbView {
 };
 
 /**
-  * The MyMoneyDbDef class is 
+  * The MyMoneyDbDef class is
   */
 class MyMoneyDbDef  {
   friend class MyMoneyStorageSql;
@@ -525,29 +531,29 @@ public:
   void modifyBudget(const MyMoneyBudget& bud);
   void removeBudget(const MyMoneyBudget& bud);
 
-  unsigned long transactionCount  (const QCString& aid = QCString()) const;
-  inline const QMap<QCString, unsigned long> transactionCountMap () const
+  unsigned long transactionCount  (const QString& aid = QString()) const;
+  inline const QMap<QString, unsigned long> transactionCountMap () const
       {return (m_transactionCountMap);};
   /**
     * the storage manager also needs the following read entry points
     */
-  const QMap<QCString, MyMoneyAccount> fetchAccounts (const QStringList& idList = QStringList (), bool forUpdate = false) const;
-  const QMap<QCString, MyMoneyMoney> fetchBalance(const QCStringList& id, const QDate& date) const;
-  const QMap<QCString, MyMoneyBudget> fetchBudgets (const QStringList& idList = QStringList (), bool forUpdate = false) const;
-  const QMap<QCString, MyMoneySecurity> fetchCurrencies (const QStringList& idList = QStringList (), bool forUpdate = false) const;
-  const QMap<QCString, MyMoneyInstitution> fetchInstitutions (const QStringList& idList = QStringList (), bool forUpdate = false) const;
-  const QMap<QCString, MyMoneyPayee> fetchPayees (const QStringList& idList = QStringList (), bool forUpdate = false) const;
+  const QMap<QString, MyMoneyAccount> fetchAccounts (const QStringList& idList = QStringList (), bool forUpdate = false) const;
+  const QMap<QString, MyMoneyMoney> fetchBalance(const QStringList& id, const QDate& date) const;
+  const QMap<QString, MyMoneyBudget> fetchBudgets (const QStringList& idList = QStringList (), bool forUpdate = false) const;
+  const QMap<QString, MyMoneySecurity> fetchCurrencies (const QStringList& idList = QStringList (), bool forUpdate = false) const;
+  const QMap<QString, MyMoneyInstitution> fetchInstitutions (const QStringList& idList = QStringList (), bool forUpdate = false) const;
+  const QMap<QString, MyMoneyPayee> fetchPayees (const QStringList& idList = QStringList (), bool forUpdate = false) const;
   const  MyMoneyPriceList fetchPrices (const QStringList& fromIdList = QStringList (), const QStringList& toIdList = QStringList(), bool forUpdate = false) const;
   const  MyMoneyPrice fetchSinglePrice (const QString& fromIdList, const QString& toIdList, const QDate& date, bool exactDate, bool forUpdate = false) const;
-  const QMap<QCString, MyMoneyReport> fetchReports (const QStringList& idList = QStringList (), bool forUpdate = false) const;
-  const QMap<QCString, MyMoneySchedule> fetchSchedules (const QStringList& idList = QStringList (), bool forUpdate = false) const;
-  const QMap<QCString, MyMoneySecurity> fetchSecurities (const QStringList& idList = QStringList (), bool forUpdate = false) const;
-  const QMap<QCString, MyMoneyTransaction> fetchTransactions (const QString& tidList = QString (), const QString& dateClause = QString(), bool forUpdate = false) const;
-  const QMap<QCString, MyMoneyTransaction> fetchTransactions (const MyMoneyTransactionFilter& filter) const;
-  bool isReferencedByTransaction(const QCString& id) const;
+  const QMap<QString, MyMoneyReport> fetchReports (const QStringList& idList = QStringList (), bool forUpdate = false) const;
+  const QMap<QString, MyMoneySchedule> fetchSchedules (const QStringList& idList = QStringList (), bool forUpdate = false) const;
+  const QMap<QString, MyMoneySecurity> fetchSecurities (const QStringList& idList = QStringList (), bool forUpdate = false) const;
+  const QMap<QString, MyMoneyTransaction> fetchTransactions (const QString& tidList = QString (), const QString& dateClause = QString(), bool forUpdate = false) const;
+  const QMap<QString, MyMoneyTransaction> fetchTransactions (const MyMoneyTransactionFilter& filter) const;
+  bool isReferencedByTransaction(const QString& id) const;
 
-  void readPayees(const QCString&);
-  void readPayees(const QValueList<QCString> payeeList = QValueList<QCString>());
+  void readPayees(const QString&);
+  void readPayees(const QValueList<QString> payeeList = QValueList<QString>());
   void readTransactions(const MyMoneyTransactionFilter& filter);
   void setProgressCallback(void(*callback)(int, int, const QString&));
 
@@ -558,33 +564,33 @@ public:
   bool endCommitUnit (const QString& callingFunction);
   void cancelCommitUnit (const QString& callingFunction);
 
-  long long unsigned getRecCount(const QString& table) const;
-  long long unsigned getNextBudgetId() const;
-  long long unsigned getNextAccountId() const;
-  long long unsigned getNextInstitutionId() const;
-  long long unsigned getNextPayeeId() const;
-  long long unsigned getNextReportId() const;
-  long long unsigned getNextScheduleId() const;
-  long long unsigned getNextSecurityId() const;
-  long long unsigned getNextTransactionId() const;
+  long unsigned getRecCount(const QString& table) const;
+  long unsigned getNextBudgetId() const;
+  long unsigned getNextAccountId() const;
+  long unsigned getNextInstitutionId() const;
+  long unsigned getNextPayeeId() const;
+  long unsigned getNextReportId() const;
+  long unsigned getNextScheduleId() const;
+  long unsigned getNextSecurityId() const;
+  long unsigned getNextTransactionId() const;
 
-  long long unsigned incrementBudgetId();
-  long long unsigned incrementAccountId();
-  long long unsigned incrementInstitutionId();
-  long long unsigned incrementPayeeId();
-  long long unsigned incrementReportId();
-  long long unsigned incrementScheduleId();
-  long long unsigned incrementSecurityId();
-  long long unsigned incrementTransactionId();
+  long unsigned incrementBudgetId();
+  long unsigned incrementAccountId();
+  long unsigned incrementInstitutionId();
+  long unsigned incrementPayeeId();
+  long unsigned incrementReportId();
+  long unsigned incrementScheduleId();
+  long unsigned incrementSecurityId();
+  long unsigned incrementTransactionId();
 
-  void loadAccountId(const unsigned long long id);
-  void loadTransactionId(const unsigned long long id);
-  void loadPayeeId(const unsigned long long id);
-  void loadInstitutionId(const unsigned long long id);
-  void loadScheduleId(const unsigned long long id);
-  void loadSecurityId(const unsigned long long id);
-  void loadReportId(const unsigned long long id);
-  void loadBudgetId(const unsigned long long id);
+  void loadAccountId(const unsigned long& id);
+  void loadTransactionId(const unsigned long& id);
+  void loadPayeeId(const unsigned long& id);
+  void loadInstitutionId(const unsigned long& id);
+  void loadScheduleId(const unsigned long& id);
+  void loadSecurityId(const unsigned long& id);
+  void loadReportId(const unsigned long& id);
+  void loadBudgetId(const unsigned long& id);
 
 private:
   // a function to build a comprehensive error message
@@ -616,7 +622,7 @@ private:
   void writeCurrency(const MyMoneySecurity& currency, MyMoneySqlQuery& q);
   void writeReport (const MyMoneyReport& rep, MyMoneySqlQuery& q);
   void writeBudget (const MyMoneyBudget& bud, MyMoneySqlQuery& q);
-  void writeKeyValuePairs(const QString& kvpType, const QString& kvpId, const QMap<QCString, QString>& pairs);
+  void writeKeyValuePairs(const QString& kvpType, const QString& kvpId, const QMap<QString, QString>& pairs);
   void writeKeyValuePair(const QString& kvpType, const QString& kvpId,
                          const QString& kvpKey, const QString& kvpData);
   // read routines
@@ -641,7 +647,7 @@ private:
   void deleteTransaction(const QString& id);
   void deleteSchedule(const QString& id);
   void deleteKeyValuePairs(const QString& kvpType, const QString& kvpId);
-  long long unsigned calcHighId (const long long unsigned, const QString&);
+  long unsigned calcHighId (const long unsigned&, const QString&);
 
   void setVersion (const QString& version);
 
@@ -675,6 +681,22 @@ private:
   int upgradeDb();
   int upgradeToV1();
   int upgradeToV2();
+  int upgradeToV3();
+  int upgradeToV4();
+  int upgradeToV5();
+  int upgradeToV6();
+  bool sqliteAlterTable(const MyMoneyDbTable& t);
+  bool addColumn(const MyMoneyDbTable& t,
+                 const MyMoneyDbColumn& c,
+                 const QString& after = QString());
+  bool addColumn(const QString& table,
+                 const QString& column,
+                 const QString& after = QString());
+  bool dropColumn(const MyMoneyDbTable& t,
+                  const QString& c);
+  bool dropColumn(const QString& table,
+                  const QString& column);
+
 //  long long unsigned getRecCount(const QString& table);
   int createTables();
   void createTable(const MyMoneyDbTable& t);
@@ -685,41 +707,36 @@ private:
   databaseTypeE m_dbType;
 
   MyMoneyDbDef m_db;
-  unsigned int m_majorVersion;
-  unsigned int m_minorVersion;
+  unsigned int m_dbVersion;
   IMyMoneySerialize *m_storage;
   IMyMoneyStorage *m_storagePtr;
   // input options
-  unsigned int m_mode; // 0 = old method (file mode) 1 = single-user, 2 = multi-user (NYI)
-
   bool m_loadAll; // preload all data
   bool m_override; // override open if already in use
-
-  bool m_isDbaseMode;
   // error message
   QString m_error;
   // record counts
-  long long unsigned m_institutions;
-  long long unsigned m_accounts;
-  long long unsigned m_payees;
-  long long unsigned m_transactions;
-  long long unsigned m_splits;
-  long long unsigned m_securities;
-  long long unsigned m_prices;
-  long long unsigned m_currencies;
-  long long unsigned m_schedules;
-  long long unsigned m_reports;
-  long long unsigned m_kvps;
-  long long unsigned m_budgets;
+  long unsigned m_institutions;
+  long unsigned m_accounts;
+  long unsigned m_payees;
+  long unsigned m_transactions;
+  long unsigned m_splits;
+  long unsigned m_securities;
+  long unsigned m_prices;
+  long unsigned m_currencies;
+  long unsigned m_schedules;
+  long unsigned m_reports;
+  long unsigned m_kvps;
+  long unsigned m_budgets;
   // next id to use (for future archive)
-  long long unsigned m_hiIdInstitutions;
-  long long unsigned m_hiIdPayees;
-  long long unsigned m_hiIdAccounts;
-  long long unsigned m_hiIdTransactions;
-  long long unsigned m_hiIdSchedules;
-  long long unsigned m_hiIdSecurities;
-  long long unsigned m_hiIdReports;
-  long long unsigned m_hiIdBudgets;
+  long unsigned m_hiIdInstitutions;
+  long unsigned m_hiIdPayees;
+  long unsigned m_hiIdAccounts;
+  long unsigned m_hiIdTransactions;
+  long unsigned m_hiIdSchedules;
+  long unsigned m_hiIdSecurities;
+  long unsigned m_hiIdReports;
+  long unsigned m_hiIdBudgets;
   // encrypt option - usage TBD
   QString m_encryptData;
 
@@ -741,12 +758,12 @@ private:
    * This member variable holds a list of those accounts for which all
    * transactions are in memory, thus saving reading them again
    */
-//  QValueList<QCString> m_accountsLoaded;
+//  QValueList<QString> m_accountsLoaded;
   /**
     * This member variable is used when loading transactions to list all
     * referenced payees, which can then be read into memory (if not already there)
     */
-//  QValueList<QCString> m_payeeList;
+//  QValueList<QString> m_payeeList;
 
   void alert(QString s) const {qDebug("%s", s.ascii());}; // FIXME: remove...
   /** The following keeps track of commitment units (known as transactions in SQL
@@ -771,7 +788,7 @@ private:
     * probably be moved into the MyMoneyAccount object; maybe we will do that once
     * the database code has been properly checked out
     */
-  QMap<QCString, unsigned long> m_transactionCountMap;
+  QMap<QString, unsigned long> m_transactionCountMap;
   /**
     * These member variables hold the user name and date/time of logon
     */
@@ -782,5 +799,7 @@ private:
   //Disable copying
   MyMoneyStorageSql (const MyMoneyStorageSql& rhs);
   MyMoneyStorageSql& operator= (const MyMoneyStorageSql& rhs);
+  //
+  bool m_newDatabase;
 };
 #endif // MYMONEYSTORAGESQL_H
