@@ -239,7 +239,7 @@ void PivotTableTest::testSubAccount()
   MyMoneyReport filter;
   filter.setRowType( MyMoneyReport::eExpenseIncome );
   filter.setDateFilter(QDate(2004,9,1),QDate(2005,1,1).addDays(-1));
-  filter.setShowSubAccounts(true);
+  filter.setDetailLevel(MyMoneyReport::eDetailAll);
   filter.setName("Spending with Sub-Account");
   XMLandback(filter);
   PivotTable spending_f( filter );
@@ -392,10 +392,10 @@ void PivotTableTest::testMultipleCurrencies()
   MyMoneyMoney moCanTransaction( 100.0 );
   MyMoneyMoney moJpyTransaction( 100.0 );
 
-  QCString acCanChecking = makeAccount(QString("Canadian Checking"),MyMoneyAccount::Checkings,moCanOpening,QDate(2003,11,15),acAsset,"CAD");
-  QCString acJpyChecking = makeAccount(QString("Japanese Checking"),MyMoneyAccount::Checkings,moJpyOpening,QDate(2003,11,15),acAsset,"JPY");
-  QCString acCanCash = makeAccount(QString("Canadian"),MyMoneyAccount::Expense,0,QDate(2004,2,11),acForeign,"CAD");
-  QCString acJpyCash = makeAccount(QString("Japanese"),MyMoneyAccount::Expense,0,QDate(2004,2,11),acForeign,"JPY");
+  QString acCanChecking = makeAccount(QString("Canadian Checking"),MyMoneyAccount::Checkings,moCanOpening,QDate(2003,11,15),acAsset,"CAD");
+  QString acJpyChecking = makeAccount(QString("Japanese Checking"),MyMoneyAccount::Checkings,moJpyOpening,QDate(2003,11,15),acAsset,"JPY");
+  QString acCanCash = makeAccount(QString("Canadian"),MyMoneyAccount::Expense,0,QDate(2004,2,11),acForeign,"CAD");
+  QString acJpyCash = makeAccount(QString("Japanese"),MyMoneyAccount::Expense,0,QDate(2004,2,11),acForeign,"JPY");
 
   makePrice("CAD",QDate(2004,1,1),MyMoneyMoney(moCanPrice));
   makePrice("JPY",QDate(2004,1,1),MyMoneyMoney(moJpyPrice));
@@ -422,7 +422,7 @@ void PivotTableTest::testMultipleCurrencies()
   MyMoneyReport filter;
   filter.setRowType( MyMoneyReport::eExpenseIncome );
   filter.setDateFilter(QDate(2004,1,1),QDate(2005,1,1).addDays(-1));
-  filter.setShowSubAccounts(true);
+  filter.setDetailLevel(MyMoneyReport::eDetailAll);
   filter.setConvertCurrency(true);
   filter.setName("Multiple Currency Spending Rerport (with currency conversion)");
   XMLandback(filter);
@@ -445,7 +445,7 @@ void PivotTableTest::testMultipleCurrencies()
 
   // Test the report type where we DO NOT convert the currency
   filter.setConvertCurrency(false);
-  filter.setShowSubAccounts(true);
+  filter.setDetailLevel(MyMoneyReport::eDetailAll);
   filter.setName("Multiple Currency Spending Report (WITHOUT currency conversion)");
   XMLandback(filter);
   PivotTable spending_fnc( filter );
@@ -514,7 +514,7 @@ void PivotTableTest::testAdvancedFilter()
     TransactionHelper t1( QDate(2004,10,31), MyMoneySplit::ActionWithdrawal, moSolo, acChecking, acSolo );
     TransactionHelper t2( QDate(2004,11,7), MyMoneySplit::ActionWithdrawal, moParent1, acCredit, acParent );
     TransactionHelper t3( QDate(2004,11,7), MyMoneySplit::ActionWithdrawal, moChild, acCredit, acChild );
-    TransactionHelper t4( QDate(2004,11,7), MyMoneySplit::ActionWithdrawal, moThomas, acCredit, acParent, QCString(), "Thomas Baumgart" );
+    TransactionHelper t4( QDate(2004,11,7), MyMoneySplit::ActionWithdrawal, moThomas, acCredit, acParent, QString(), "Thomas Baumgart" );
 
     MyMoneyReport filter;
     filter.setRowType( MyMoneyReport::eExpenseIncome );
@@ -533,12 +533,12 @@ void PivotTableTest::testAdvancedFilter()
     TransactionHelper t1( QDate(2004,10,31), MyMoneySplit::ActionWithdrawal, moSolo, acChecking, acSolo );
     TransactionHelper t2( QDate(2004,11,7), MyMoneySplit::ActionWithdrawal, moParent1, acCredit, acParent );
     TransactionHelper t3( QDate(2004,11,7), MyMoneySplit::ActionWithdrawal, moChild, acCredit, acChild );
-    TransactionHelper t4( QDate(2004,11,7), MyMoneySplit::ActionWithdrawal, moNoPayee, acCredit, acParent, QCString(), QString() );
+    TransactionHelper t4( QDate(2004,11,7), MyMoneySplit::ActionWithdrawal, moNoPayee, acCredit, acParent, QString(), QString() );
 
     MyMoneyReport filter;
     filter.setRowType( MyMoneyReport::eExpenseIncome );
     filter.setDateFilter(QDate(2004,1,1),QDate(2005,1,1).addDays(-1));
-    filter.addPayee(QCString());
+    filter.addPayee(QString());
     XMLandback(filter);
     PivotTable spending_f( filter );
     CPPUNIT_ASSERT(spending_f.m_grid["Expense"]["Parent"][acParent][eActual][11]==moNoPayee);
@@ -550,7 +550,7 @@ void PivotTableTest::testAdvancedFilter()
     TransactionHelper t1( QDate(2004,10,31), MyMoneySplit::ActionWithdrawal, moSolo, acChecking, acSolo );
     TransactionHelper t2( QDate(2004,11,7), MyMoneySplit::ActionWithdrawal, moParent1, acCredit, acParent );
     TransactionHelper t3( QDate(2004,11,7), MyMoneySplit::ActionWithdrawal, moChild, acCredit, acChild );
-    TransactionHelper t4( QDate(2004,11,7), MyMoneySplit::ActionWithdrawal, moThomas, acCredit, acParent, QCString(), "Thomas Baumgart" );
+    TransactionHelper t4( QDate(2004,11,7), MyMoneySplit::ActionWithdrawal, moThomas, acCredit, acParent, QString(), "Thomas Baumgart" );
 
     MyMoneyReport filter;
     filter.setRowType( MyMoneyReport::eExpenseIncome );
@@ -875,12 +875,12 @@ void PivotTableTest::testInvestment(void)
 
   // Transactions
   //                         Date             Action                              Shares  Price   Stock     Asset       Income
-  InvTransactionHelper s1b1( QDate(2004,2,1), MyMoneySplit::ActionBuyShares,      1000.00, 100.00, acStock1, acChecking, QCString() );
-  InvTransactionHelper s1b2( QDate(2004,3,1), MyMoneySplit::ActionBuyShares,      1000.00, 110.00, acStock1, acChecking, QCString() );
-  InvTransactionHelper s1s1( QDate(2004,4,1), MyMoneySplit::ActionBuyShares,      -200.00, 120.00, acStock1, acChecking, QCString() );
-  InvTransactionHelper s1s2( QDate(2004,5,1), MyMoneySplit::ActionBuyShares,      -200.00, 100.00, acStock1, acChecking, QCString() );
-  InvTransactionHelper s1r1( QDate(2004,6,1), MyMoneySplit::ActionReinvestDividend, 50.00, 100.00, acStock1, QCString(), acDividends );
-  InvTransactionHelper s1r2( QDate(2004,7,1), MyMoneySplit::ActionReinvestDividend, 50.00,  80.00, acStock1, QCString(), acDividends );
+  InvTransactionHelper s1b1( QDate(2004,2,1), MyMoneySplit::ActionBuyShares,      1000.00, 100.00, acStock1, acChecking, QString() );
+  InvTransactionHelper s1b2( QDate(2004,3,1), MyMoneySplit::ActionBuyShares,      1000.00, 110.00, acStock1, acChecking, QString() );
+  InvTransactionHelper s1s1( QDate(2004,4,1), MyMoneySplit::ActionBuyShares,      -200.00, 120.00, acStock1, acChecking, QString() );
+  InvTransactionHelper s1s2( QDate(2004,5,1), MyMoneySplit::ActionBuyShares,      -200.00, 100.00, acStock1, acChecking, QString() );
+  InvTransactionHelper s1r1( QDate(2004,6,1), MyMoneySplit::ActionReinvestDividend, 50.00, 100.00, acStock1, QString(), acDividends );
+  InvTransactionHelper s1r2( QDate(2004,7,1), MyMoneySplit::ActionReinvestDividend, 50.00,  80.00, acStock1, QString(), acDividends );
   InvTransactionHelper s1c1( QDate(2004,8,1), MyMoneySplit::ActionDividend,         10.00, 100.00, acStock1, acChecking, acDividends );
   InvTransactionHelper s1c2( QDate(2004,9,1), MyMoneySplit::ActionDividend,         10.00, 120.00, acStock1, acChecking, acDividends );
 
@@ -947,8 +947,11 @@ void PivotTableTest::testBudget(void)
     BudgetHelper budget;
     budget += BudgetEntryHelper( QDate(2006,1,1), acSolo, false, 100.0 );
 
-    MyMoneyReport report(MyMoneyReport::eBudgetActual,MyMoneyReport::eMonths,MyMoneyTransactionFilter::yearToDate,
-      false,"Yearly Budgeted vs. Actual","Default Report");
+    MyMoneyReport report(MyMoneyReport::eBudgetActual,
+                         MyMoneyReport::eMonths,
+                         MyMoneyTransactionFilter::yearToDate,
+                         MyMoneyReport::eDetailTop,
+                         "Yearly Budgeted vs. Actual","Default Report");
     PivotTable table(report);
   }
 
@@ -956,8 +959,11 @@ void PivotTableTest::testBudget(void)
   {
     BudgetHelper budget;
     budget += BudgetEntryHelper( QDate(2006,1,1), acParent, false, 100.0 );
-    MyMoneyReport report(MyMoneyReport::eBudgetActual,MyMoneyReport::eMonths,MyMoneyTransactionFilter::yearToDate,
-      false,"Yearly Budgeted vs. Actual","Default Report");
+    MyMoneyReport report(MyMoneyReport::eBudgetActual,
+                         MyMoneyReport::eMonths,
+                         MyMoneyTransactionFilter::yearToDate,
+                         MyMoneyReport::eDetailTop,
+                         "Yearly Budgeted vs. Actual","Default Report");
     PivotTable table(report);
   }
 
@@ -969,8 +975,11 @@ void PivotTableTest::testBudget(void)
   {
     BudgetHelper budget;
     budget += BudgetEntryHelper( QDate(2006,1,1), acParent, true, 100.0 );
-    MyMoneyReport report(MyMoneyReport::eBudgetActual,MyMoneyReport::eMonths,MyMoneyTransactionFilter::yearToDate,
-      false,"Yearly Budgeted vs. Actual","Default Report");
+    MyMoneyReport report(MyMoneyReport::eBudgetActual,
+                         MyMoneyReport::eMonths,
+                         MyMoneyTransactionFilter::yearToDate,
+                         MyMoneyReport::eDetailTop ,
+                         "Yearly Budgeted vs. Actual","Default Report");
     PivotTable table(report);
   }
 
@@ -983,8 +992,11 @@ void PivotTableTest::testBudget(void)
     budget += BudgetEntryHelper( QDate(2006,1,1), acParent, false, 100.0 );
     budget += BudgetEntryHelper( QDate(2006,1,1), acChild, false, 100.0 );
     budget += BudgetEntryHelper( QDate(2006,1,1), acSecondChild, true, 100.0 );
-    MyMoneyReport report(MyMoneyReport::eBudgetActual,MyMoneyReport::eMonths,MyMoneyTransactionFilter::yearToDate,
-      false,"Yearly Budgeted vs. Actual","Default Report");
+    MyMoneyReport report(MyMoneyReport::eBudgetActual,
+                         MyMoneyReport::eMonths,
+                         MyMoneyTransactionFilter::yearToDate,
+                         MyMoneyReport::eDetailTop,
+                         "Yearly Budgeted vs. Actual","Default Report");
     PivotTable table(report);
   }
 
@@ -997,8 +1009,11 @@ void PivotTableTest::testBudget(void)
   {
     BudgetHelper budget;
     budget += BudgetEntryHelper( QDate(2006,1,1), acSolo, false, 100.0 );
-    MyMoneyReport report(MyMoneyReport::eBudgetActual,MyMoneyReport::eMonths,MyMoneyTransactionFilter::yearToDate,
-      false,"Yearly Budgeted vs. Actual","Default Report");
+    MyMoneyReport report(MyMoneyReport::eBudgetActual,
+                         MyMoneyReport::eMonths,
+                         MyMoneyTransactionFilter::yearToDate,
+                         MyMoneyReport::eDetailTop,
+                         "Yearly Budgeted vs. Actual","Default Report");
     PivotTable table(report);
   }
 }
