@@ -301,10 +301,10 @@ void KReportsView::KReportTab::toggleChart(void)
   * KReportsView Implementation
   */
 
-class KReportsViewPrivate
+class KReportsView::Private
 {
 public:
-  KReportsViewPrivate() :
+  Private() :
     includeCSS(0) {}
 
   QCheckBox* includeCSS;
@@ -312,11 +312,11 @@ public:
 
 KReportsView::KReportsView(QWidget *parent, const char *name ) :
   KMyMoneyViewBase(parent, name, i18n("Reports")),
-  d(new KReportsViewPrivate),
+  d(new Private),
   m_needReload(false)
 {
   m_reportTabWidget = new KTabWidget( this, "m_reportTabWidget" );
-  m_viewLayout->addWidget( m_reportTabWidget );
+  addWidget( m_reportTabWidget );
   m_reportTabWidget->setHoverCloseButton( true );
 
   m_listTab = (new QWidget( m_reportTabWidget, "indextab" ));
@@ -529,7 +529,7 @@ void KReportsView::loadView(void)
 void KReportsView::slotOpenURL(const KURL &url, const KParts::URLArgs& /* args */)
 {
   QString view = url.fileName(false);
-  QCString command = url.queryItem("command").data();
+  QString command = url.queryItem("command").data();
 
   if(view == VIEW_REPORTS) {
 
@@ -703,7 +703,7 @@ void KReportsView::slotDelete(void)
   }
 }
 
-void KReportsView::slotOpenReport(const QCString& id)
+void KReportsView::slotOpenReport(const QString& id)
 {
   if ( ! id.isEmpty() )
   {
@@ -937,7 +937,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eExpenseIncome,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::currentMonth,
-      true,
+      MyMoneyReport::eDetailAll,
       i18n("Income and Expenses This Month"),
       i18n("Default Report")
     ));
@@ -945,22 +945,29 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eExpenseIncome,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::yearToDate,
-      true,
+      MyMoneyReport::eDetailAll,
       i18n("Income and Expenses This Year"),
       i18n("Default Report")
     ));
+    list.push_back(MyMoneyReport(
+      MyMoneyReport::eExpenseIncome,
+      MyMoneyReport::eYears,
+      MyMoneyTransactionFilter::allDates,
+      MyMoneyReport::eDetailAll,
+      i18n("Income and Expenses By Year"),
+      i18n("Default Report")
+    ));
 
 #ifdef HAVE_KDCHART
     list.push_back(MyMoneyReport(
       MyMoneyReport::eExpenseIncome,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::yearToDate,
-      true,
+      MyMoneyReport::eDetailTop,
       i18n("Income and Expenses Graph"),
       i18n("Default Report")
     ));
     list.back().setChartByDefault(true);
-    list.back().setDetailLevel(MyMoneyReport::eDetailTop);
     list.back().setChartType(MyMoneyReport::eChartLine);
     list.back().setChartDataLabels(false);
 
@@ -968,12 +975,11 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eExpenseIncome,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailGroup,
       i18n("Income and Expenses Pie Chart"),
       i18n("Default Report")
     ));
     list.back().setChartByDefault(true);
-    list.back().setDetailLevel(MyMoneyReport::eDetailGroup);
     list.back().setChartType(MyMoneyReport::eChartPie);
     list.back().setShowingRowTotals(false);
 #endif
@@ -987,15 +993,15 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAssetLiability,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailTop,
       i18n("Net Worth By Month"),
       i18n("Default Report")
     ));
     list.push_back(MyMoneyReport(
       MyMoneyReport::eAssetLiability,
       MyMoneyReport::eMonths,
-      MyMoneyTransactionFilter::currentMonth,
-      false,
+      MyMoneyTransactionFilter::today,
+      MyMoneyReport::eDetailTop,
       i18n("Net Worth Today"),
       i18n("Default Report")
     ));
@@ -1003,7 +1009,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAssetLiability,
       MyMoneyReport::eYears,
       MyMoneyTransactionFilter::allDates,
-      false,
+      MyMoneyReport::eDetailTop,
       i18n("Net Worth By Year"),
       i18n("Default Report")
     ));
@@ -1011,7 +1017,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAssetLiability,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::next7Days,
-      false,
+      MyMoneyReport::eDetailTop,
       i18n("7-day Cash Flow Forecast"),
       i18n("Default Report")
     ));
@@ -1023,20 +1029,19 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAssetLiability,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::last12Months,
-      false,
+      MyMoneyReport::eDetailTotal,
       i18n("Net Worth Graph"),
       i18n("Default Report")
     ));
     list.back().setChartByDefault(true);
     list.back().setChartGridLines(false);
-    list.back().setDetailLevel(MyMoneyReport::eDetailTotal);
     list.back().setChartType(MyMoneyReport::eChartLine);
 
     list.push_back(MyMoneyReport(
       MyMoneyReport::eInstitution,
       MyMoneyReport::eQCnone,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailTop,
       i18n("Account Balances by Institution"),
       i18n("Default Report")
     ));
@@ -1046,7 +1051,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAccountType,
       MyMoneyReport::eQCnone,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailTop,
       i18n("Account Balances by Type"),
       i18n("Default Report")
     ));
@@ -1060,7 +1065,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAccount,
       MyMoneyReport::eQCnumber|MyMoneyReport::eQCpayee|MyMoneyReport::eQCcategory|MyMoneyReport::eQCbalance,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Transactions by Account"),
       i18n("Default Report")
     ));
@@ -1069,7 +1074,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eCategory,
       MyMoneyReport::eQCnumber|MyMoneyReport::eQCpayee|MyMoneyReport::eQCaccount,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Transactions by Category"),
       i18n("Default Report")
     ));
@@ -1077,7 +1082,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::ePayee,
       MyMoneyReport::eQCnumber|MyMoneyReport::eQCcategory,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Transactions by Payee"),
       i18n("Default Report")
     ));
@@ -1085,7 +1090,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eMonth,
       MyMoneyReport::eQCnumber|MyMoneyReport::eQCpayee|MyMoneyReport::eQCcategory,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Transactions by Month"),
       i18n("Default Report")
     ));
@@ -1093,7 +1098,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eWeek,
       MyMoneyReport::eQCnumber|MyMoneyReport::eQCpayee|MyMoneyReport::eQCcategory,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Transactions by Week"),
       i18n("Default Report")
     ));
@@ -1101,7 +1106,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAccount,
       MyMoneyReport::eQCloan,
       MyMoneyTransactionFilter::allDates,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Loan Transactions"),
       i18n("Default Report")
     ));
@@ -1110,12 +1115,24 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAccountReconcile,
       MyMoneyReport::eQCnumber|MyMoneyReport::eQCpayee|MyMoneyReport::eQCcategory|MyMoneyReport::eQCbalance,
       MyMoneyTransactionFilter::last3Months,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Transactions by Reconciliation Status"),
       i18n("Default Report")
     ));
     groups.push_back(list);
   }
+  {
+    ReportGroup list("CashFlow", i18n("Cash Flow"));
+    list.push_back(MyMoneyReport(
+      MyMoneyReport::eCashFlow,
+      MyMoneyReport::eQCnumber|MyMoneyReport::eQCpayee|MyMoneyReport::eQCaccount,
+      MyMoneyTransactionFilter::yearToDate,
+      MyMoneyReport::eDetailAll,
+      i18n("Cash Flow Transactions This Month"),
+      i18n("Default Report")
+    ));
+    groups.push_back(list);
+  }
   {
     ReportGroup list("Investments", i18n("Investments"));
 
@@ -1123,7 +1140,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eTopAccount,
       MyMoneyReport::eQCaction|MyMoneyReport::eQCshares|MyMoneyReport::eQCprice,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Investment Transactions"),
       i18n("Default Report")
     ));
@@ -1133,7 +1150,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAccountByTopAccount,
       MyMoneyReport::eQCshares|MyMoneyReport::eQCprice,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Investment Holdings by Account"),
       i18n("Default Report")
     ));
@@ -1143,7 +1160,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eEquityType,
       MyMoneyReport::eQCshares|MyMoneyReport::eQCprice,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Investment Holdings by Type"),
       i18n("Default Report")
     ));
@@ -1153,7 +1170,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAccountByTopAccount,
       MyMoneyReport::eQCperformance,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Investment Performance by Account"),
       i18n("Default Report")
     ));
@@ -1163,7 +1180,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eEquityType,
       MyMoneyReport::eQCperformance,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Investment Performance by Type"),
       i18n("Default Report")
     ));
@@ -1173,13 +1190,12 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAssetLiability,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::today,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Investment Holdings Pie"),
       i18n("Default Report")
     ));
     list.back().setChartByDefault(true);
     list.back().setChartGridLines(false);
-    list.back().setDetailLevel(MyMoneyReport::eDetailAll);
     list.back().setChartType(MyMoneyReport::eChartPie);
     list.back().setInvestmentsOnly(true);
 
@@ -1187,17 +1203,83 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAssetLiability,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::last12Months,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Investment Worth Graph"),
       i18n("Default Report")
     ));
     list.back().setChartByDefault(true);
     list.back().setChartGridLines(false);
-    list.back().setDetailLevel(MyMoneyReport::eDetailAll);
     list.back().setChartType(MyMoneyReport::eChartLine);
     list.back().setColumnsAreDays( true );
     list.back().setInvestmentsOnly(true);
 
+    list.push_back(MyMoneyReport(
+      MyMoneyReport::eAssetLiability,
+      MyMoneyReport::eMonths,
+      MyMoneyTransactionFilter::last12Months,
+      MyMoneyReport::eDetailAll,
+      i18n("Investment Price Graph"),
+      i18n("Default Report")
+    ));
+    list.back().setChartByDefault(true);
+    list.back().setChartGridLines(false);
+    list.back().setChartType(MyMoneyReport::eChartLine);
+    list.back().setColumnsAreDays( true );
+    list.back().setInvestmentsOnly(true);
+    list.back().setIncludingBudgetActuals(false);
+    list.back().setIncludingPrice(true);
+    list.back().setConvertCurrency(true);
+
+    list.push_back(MyMoneyReport(
+      MyMoneyReport::eAssetLiability,
+      MyMoneyReport::eMonths,
+      MyMoneyTransactionFilter::last12Months,
+      MyMoneyReport::eDetailAll,
+      i18n("Investment Moving Average Price Graph"),
+      i18n("Default Report")
+    ));
+    list.back().setChartByDefault(true);
+    list.back().setChartGridLines(false);
+    list.back().setChartType(MyMoneyReport::eChartLine);
+    list.back().setColumnsAreDays( true );
+    list.back().setInvestmentsOnly(true);
+    list.back().setIncludingBudgetActuals(false);
+    list.back().setIncludingAveragePrice(true);
+    list.back().setMovingAverageDays(10);
+    list.back().setConvertCurrency(true);
+
+    list.push_back(MyMoneyReport(
+      MyMoneyReport::eAssetLiability,
+      MyMoneyReport::eMonths,
+      MyMoneyTransactionFilter::last30Days,
+      MyMoneyReport::eDetailAll,
+      i18n("Investment Moving Average"),
+      i18n("Default Report")
+    ));
+    list.back().setChartGridLines(false);
+    list.back().setChartType(MyMoneyReport::eChartLine);
+    list.back().setColumnsAreDays( true );
+    list.back().setInvestmentsOnly(true);
+    list.back().setIncludingBudgetActuals(false);
+    list.back().setIncludingMovingAverage(true);
+    list.back().setMovingAverageDays(10);
+
+    list.push_back(MyMoneyReport(
+      MyMoneyReport::eAssetLiability,
+      MyMoneyReport::eMonths,
+      MyMoneyTransactionFilter::last30Days,
+      MyMoneyReport::eDetailAll,
+      i18n("Investment Moving Average vs Actual"),
+      i18n("Default Report")
+    ));
+    list.back().setChartByDefault(true);
+    list.back().setChartGridLines(false);
+    list.back().setChartType(MyMoneyReport::eChartLine);
+    list.back().setColumnsAreDays( true );
+    list.back().setInvestmentsOnly(true);
+    list.back().setIncludingBudgetActuals(true);
+    list.back().setIncludingMovingAverage(true);
+    list.back().setMovingAverageDays(10);
 #endif
     groups.push_back(list);
   }
@@ -1208,7 +1290,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eCategory,
       MyMoneyReport::eQCnumber|MyMoneyReport::eQCpayee|MyMoneyReport::eQCaccount,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Tax Transactions by Category"),
       i18n("Default Report")
     ));
@@ -1217,7 +1299,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::ePayee,
       MyMoneyReport::eQCnumber|MyMoneyReport::eQCcategory|MyMoneyReport::eQCaccount,
       MyMoneyTransactionFilter::yearToDate,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Tax Transactions by Payee"),
       i18n("Default Report")
     ));
@@ -1226,7 +1308,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eCategory,
       MyMoneyReport::eQCnumber|MyMoneyReport::eQCpayee|MyMoneyReport::eQCaccount,
       MyMoneyTransactionFilter::lastFiscalYear,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Tax Transactions by Category Last Fiscal Year"),
       i18n("Default Report")
     ));
@@ -1235,7 +1317,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::ePayee,
       MyMoneyReport::eQCnumber|MyMoneyReport::eQCcategory|MyMoneyReport::eQCaccount,
       MyMoneyTransactionFilter::lastFiscalYear,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Tax Transactions by Payee Last Fiscal Year"),
       i18n("Default Report")
     ));
@@ -1249,18 +1331,33 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eBudgetActual,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::yearToDate,
-      true,
+      MyMoneyReport::eDetailAll,
       i18n("Budgeted vs. Actual This Year"),
       i18n("Default Report")
     ));
     list.back().setShowingRowTotals(true);
     list.back().setBudget("Any",true);
 
+    list.push_back(MyMoneyReport(
+      MyMoneyReport::eBudgetActual,
+      MyMoneyReport::eMonths,
+      MyMoneyTransactionFilter::yearToMonth,
+      MyMoneyReport::eDetailAll,
+      i18n("Budgeted vs. Actual This Year (YTM)"),
+      i18n("Default Report")
+    ));
+    list.back().setShowingRowTotals(true);
+    list.back().setBudget("Any",true);
+    // in case we're in January, we show the last year
+    if(QDate::currentDate().month() == 1) {
+      list.back().setDateFilter(MyMoneyTransactionFilter::lastYear);
+    }
+
     list.push_back(MyMoneyReport(
       MyMoneyReport::eBudgetActual,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::currentMonth,
-      true,
+      MyMoneyReport::eDetailAll,
       i18n("Monthly Budgeted vs. Actual"),
       i18n("Default Report")
     ));
@@ -1270,7 +1367,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eBudgetActual,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::currentYear,
-      true,
+      MyMoneyReport::eDetailAll,
       i18n("Yearly Budgeted vs. Actual"),
       i18n("Default Report")
     ));
@@ -1281,7 +1378,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eBudget,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::currentMonth,
-      true,
+      MyMoneyReport::eDetailAll,
       i18n("Monthly Budget"),
       i18n("Default Report")
     ));
@@ -1291,7 +1388,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eBudget,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::currentYear,
-      true,
+      MyMoneyReport::eDetailAll,
       i18n("Yearly Budget"),
       i18n("Default Report")
     ));
@@ -1302,14 +1399,13 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eBudgetActual,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::currentYear,
-      true,
+      MyMoneyReport::eDetailGroup,
       i18n("Yearly Budgeted vs Actual Graph"),
       i18n("Default Report")
     ));
     list.back().setChartByDefault(true);
     list.back().setChartGridLines(false);
     list.back().setBudget("Any",true);
-    list.back().setDetailLevel(MyMoneyReport::eDetailGroup);
     list.back().setChartType(MyMoneyReport::eChartLine);
 #endif
 
@@ -1322,7 +1418,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAssetLiability,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::next12Months,
-      false,
+      MyMoneyReport::eDetailTop,
       i18n("Forecast By Month"),
       i18n("Default Report")
     ));
@@ -1331,7 +1427,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAssetLiability,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::nextQuarter,
-      false,
+      MyMoneyReport::eDetailTop,
       i18n("Forecast Next Quarter"),
       i18n("Default Report")
     ));
@@ -1343,7 +1439,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAssetLiability,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::next3Months,
-      false,
+      MyMoneyReport::eDetailTotal,
       i18n("Net Worth Forecast Graph"),
       i18n("Default Report")
     ));
@@ -1351,7 +1447,6 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
     list.back().setIncludingForecast( true );
     list.back().setChartByDefault(true);
     list.back().setChartGridLines(false);
-    list.back().setDetailLevel(MyMoneyReport::eDetailTotal);
     list.back().setChartType(MyMoneyReport::eChartLine);
 #endif
     groups.push_back(list);
@@ -1363,7 +1458,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eSchedule,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::next12Months,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Schedule Information"),
       i18n("Default Report")
     ));
@@ -1372,7 +1467,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eSchedule,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::next12Months,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Schedule Summary Information"),
       i18n("Default Report")
     ));
@@ -1381,7 +1476,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAccountInfo,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::today,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Account Information"),
       i18n("Default Report")
     ));
@@ -1390,7 +1485,7 @@ void KReportsView::defaultReports(QValueList<ReportGroup>& groups)
       MyMoneyReport::eAccountLoanInfo,
       MyMoneyReport::eMonths,
       MyMoneyTransactionFilter::today,
-      false,
+      MyMoneyReport::eDetailAll,
       i18n("Loan Information"),
       i18n("Default Report")
     ));
