@@ -147,7 +147,8 @@ Transaction::Transaction(Register *parent, const MyMoneyTransaction& transaction
   m_erronous(false),
   m_inEdit(false),
   m_inRegisterEdit(false),
-  m_showBalance(true)
+  m_showBalance(true),
+  m_reducedIntensity(false)
 {
   MyMoneyFile* file = MyMoneyFile::instance();
 
@@ -174,7 +175,7 @@ Transaction::Transaction(Register *parent, const MyMoneyTransaction& transaction
 
   if(!m_uniqueId.isEmpty()) {
     m_uniqueId += "-";
-    QCString id;
+    QString id;
     id.setNum(uniqueId);
     m_uniqueId += id.rightJustify(3, '0');
   }
@@ -241,6 +242,9 @@ void Transaction::markAsErronous(QPainter* painter, int /* row */, int /* col */
 
 bool Transaction::paintRegisterCellSetup(QPainter* painter, int& row, int& col, QRect& cellRect, QRect& textRect, QColorGroup& cg, QBrush& brush)
 {
+  if(m_reducedIntensity)
+    cg = m_parent->palette().disabled();
+
   if(m_alternate)
     cg.setColor(QColorGroup::Base, KMyMoneyGlobalSettings::listColor());
   else
@@ -267,6 +271,15 @@ bool Transaction::paintRegisterCellSetup(QPainter* painter, int& row, int& col,
   if(m_erronous && m_parent->markErronousTransactions()) {
     painter->setPen(KMyMoneyGlobalSettings::listErronousTransactionColor());
   }
+
+  // do we need to switch to the negative balance color?
+  if(col == BalanceColumn) {
+    bool showNegative = m_balance.isNegative();
+    if(m_account.accountGroup() == MyMoneyAccount::Liability && !m_balance.isZero() )
+      showNegative = !showNegative;
+    if(showNegative)
+      painter->setPen(KMyMoneyGlobalSettings::listNegativeValueColor());
+  }
   return true;
 }
 
@@ -415,6 +428,9 @@ void Transaction::paintRegisterCell(QPainter* painter, int row, int col, const Q
     // paint the grid
     paintRegisterGrid(painter, row, col, cellRect, cg);
 
+    // possible icons
+    paintRegisterIcons(painter, row, col, cellRect, cg);
+
     // and the focus
     paintRegisterCellFocus(painter, row, col, cellRect, cg);
   }
@@ -422,6 +438,24 @@ void Transaction::paintRegisterCell(QPainter* painter, int row, int col, const Q
   painter->restore();
 }
 
+void Transaction::paintRegisterIcons(QPainter* painter, int row, int col, const QRect& /*r*/, const QColorGroup& /*cg*/)
+{
+  if(row == 0 && col == DetailColumn && painter) {
+    if(m_erronous || !m_transaction.value("kmm-attachment").isEmpty()) {
+      QRect cellRect;
+      cellRect.setX(0);
+      cellRect.setY(0);
+      cellRect.setWidth(m_parent->columnWidth(col));
+      cellRect.setHeight(m_parent->rowHeight(m_startRow + row));
+      if(m_erronous) {
+        markAsErronous(painter, row, col, cellRect);
+      }
+      if(!m_transaction.value("kmm-attachment").isEmpty()) {
+        markAttachment(painter, row, col, cellRect);
+      }
+    }
+  }
+}
 void Transaction::paintRegisterCellBackground(QPainter* painter, int row, int col, const QRect& r, const QBrush& backgroundBrush)
 {
   Q_UNUSED(row);
@@ -858,7 +892,7 @@ StdTransaction::StdTransaction(Register *parent, const MyMoneyTransaction& trans
   emit parent->itemAdded(this);
 }
 
-void StdTransaction::setupFormHeader(const QCString& id)
+void StdTransaction::setupFormHeader(const QString& id)
 {
   m_category = MyMoneyFile::instance()->accountToCategory(id);
   switch(MyMoneyFile::instance()->account(id).accountGroup()) {
@@ -873,6 +907,32 @@ void StdTransaction::setupFormHeader(const QCString& id)
   }
 }
 
+KMyMoneyRegister::Action StdTransaction::actionType(void) const
+{
+  KMyMoneyRegister::Action action=ActionNone;
+
+  // if at least one split is referencing an income or
+  // expense account, we will not call it a transfer
+  QValueList<MyMoneySplit>::const_iterator it_s;
+
+  for(it_s = m_transaction.splits().begin(); it_s != m_transaction.splits().end(); ++it_s) {
+    if((*it_s).accountId() == m_split.accountId())
+      continue;
+    MyMoneyAccount acc = MyMoneyFile::instance()->account((*it_s).accountId());
+    if(acc.accountGroup() == MyMoneyAccount::Income
+    || acc.accountGroup() == MyMoneyAccount::Expense) {
+      // otherwise, we have to determine between deposit and withdrawal
+      action = m_split.shares().isNegative() ? ActionWithdrawal : ActionDeposit;
+      break;
+    }
+  }
+    // otherwise, it's a transfer
+  if(it_s == m_transaction.splits().end())
+    action = ActionTransfer;
+
+  return action;
+}
+
 void StdTransaction::loadTab(TransactionForm* form)
 {
   TabBar* bar = form->tabBar();
@@ -881,29 +941,8 @@ void StdTransaction::loadTab(TransactionForm* form)
     bar->setTabEnabled(bar->tabAt(i)->identifier(), true);
   }
 
-  // if at least one split is referencing an income or
-  // expense account, we will not call it a transfer
-  QValueList<MyMoneySplit>::const_iterator it_s;
-
   if(m_transaction.splitCount() > 0) {
-    KMyMoneyRegister::Action action=ActionNone;
-
-    for(it_s = m_transaction.splits().begin(); it_s != m_transaction.splits().end(); ++it_s) {
-      if((*it_s).accountId() == m_split.accountId())
-        continue;
-      MyMoneyAccount acc = MyMoneyFile::instance()->account((*it_s).accountId());
-      if(acc.accountGroup() == MyMoneyAccount::Income
-      || acc.accountGroup() == MyMoneyAccount::Expense) {
-        // otherwise, we have to determine between deposit and withdrawal
-        action = m_split.shares().isNegative() ? ActionWithdrawal : ActionDeposit;
-        break;
-      }
-    }
-    // otherwise, it's a transfer
-    if(it_s == m_transaction.splits().end())
-      action = ActionTransfer;
-
-    bar->setCurrentTab(action);
+    bar->setCurrentTab(actionType());
   }
   bar->setSignalEmission(TabBar::SignalAlways);
 }
@@ -1101,7 +1140,7 @@ void StdTransaction::registerCellText(QString& txt, int& align, int row, int col
         case BalanceColumn:
           align |= Qt::AlignRight;
           if(m_showBalance)
-            txt = m_balance;
+            txt = m_balance.formatMoney(m_account.fraction());
           else
             txt = "----";
           break;
@@ -1156,37 +1195,13 @@ int StdTransaction::registerColWidth(int col, const QFontMetrics& cellFontMetric
   for(int i = firstRow; i <= lastRow; ++i) {
     int align;
     registerCellText(txt, align, i, col, 0);
-    int w = cellFontMetrics.width(txt+"  ");
+    int w = cellFontMetrics.width(txt+"   ");
     if(w > nw)
       nw = w;
   }
   return nw;
 }
 
-void StdTransaction::paintRegisterCell(QPainter* painter, int row, int col, const QRect& r, bool selected, const QColorGroup& _cg)
-{
-  Transaction::paintRegisterCell(painter, row, col, r, selected, _cg);
-
-  if(row == 0 && col == DetailColumn && painter) {
-    if(m_erronous) {
-      QRect cellRect;
-      cellRect.setX(0);
-      cellRect.setY(0);
-      cellRect.setWidth(m_parent->columnWidth(col));
-      cellRect.setHeight(m_parent->rowHeight(m_startRow + row));
-      markAsErronous(painter, row, col, cellRect);
-    }
-    if(!m_transaction.value("kmm-attachment").isEmpty()) {
-      QRect cellRect;
-      cellRect.setX(0);
-      cellRect.setY(0);
-      cellRect.setWidth(m_parent->columnWidth(col));
-      cellRect.setHeight(m_parent->rowHeight(m_startRow + row));
-      markAttachment(painter, row, col, cellRect);
-    }
-  }
-}
-
 void StdTransaction::arrangeWidgetsInForm(QMap<QString, QWidget*>& editWidgets)
 {
   if(!m_form || !m_parent)
@@ -1233,35 +1248,42 @@ void StdTransaction::arrangeWidgetsInForm(QMap<QString, QWidget*>& editWidgets)
 
 void StdTransaction::tabOrderInForm(QWidgetList& tabOrderWidgets) const
 {
-  // account
-  tabOrderWidgets.append(focusWidget(m_form->cellWidget(0, ValueColumn1)));
-
-  // cashflow direction
-  tabOrderWidgets.append(focusWidget(m_form->cellWidget(1, LabelColumn1)));
-  // payee
-  tabOrderWidgets.append(focusWidget(m_form->cellWidget(1, ValueColumn1)));
-  // make sure to have the category field and the split button as seperate tab order widgets
-  // ok, we have to have some internal knowledge about the KMyMoneyCategory object, but
-  // it's one of our own widgets, so we actually don't care. Just make sure, that we don't
-  // go haywire when someone changes the KMyMoneyCategory object ...
-  QWidget* w = m_form->cellWidget(2, ValueColumn1);
-  tabOrderWidgets.append(focusWidget(w));
-  w = dynamic_cast<QWidget*>(w->child("splitButton"));
-  if(w)
-    tabOrderWidgets.append(w);
-  // memo
-  tabOrderWidgets.append(focusWidget(m_form->cellWidget(3, ValueColumn1)));
-  // number
-  if(haveNumberField()) {
-    if((w = focusWidget(m_form->cellWidget(1, ValueColumn2))))
-      tabOrderWidgets.append(w);
+  QStringList taborder = QStringList::split(",", KMyMoneyGlobalSettings::stdTransactionFormTabOrder());
+  QStringList::const_iterator it_s = taborder.constBegin();
+  QWidget* w;
+  while(it_s != taborder.constEnd()) {
+    if(*it_s == "account") {
+      tabOrderWidgets.append(focusWidget(m_form->cellWidget(0, ValueColumn1)));
+    } else if(*it_s == "cashflow") {
+      tabOrderWidgets.append(focusWidget(m_form->cellWidget(1, LabelColumn1)));
+    } else if(*it_s == "payee") {
+      tabOrderWidgets.append(focusWidget(m_form->cellWidget(1, ValueColumn1)));
+    } else if(*it_s == "category") {
+      // make sure to have the category field and the split button as seperate tab order widgets
+      // ok, we have to have some internal knowledge about the KMyMoneyCategory object, but
+      // it's one of our own widgets, so we actually don't care. Just make sure, that we don't
+      // go haywire when someone changes the KMyMoneyCategory object ...
+      w = m_form->cellWidget(2, ValueColumn1);
+      tabOrderWidgets.append(focusWidget(w));
+      w = dynamic_cast<QWidget*>(w->child("splitButton"));
+      if(w)
+        tabOrderWidgets.append(w);
+    } else if(*it_s == "memo") {
+      tabOrderWidgets.append(focusWidget(m_form->cellWidget(3, ValueColumn1)));
+    } else if(*it_s == "number") {
+      if(haveNumberField()) {
+        if((w = focusWidget(m_form->cellWidget(1, ValueColumn2))))
+          tabOrderWidgets.append(w);
+      }
+    } else if(*it_s == "date") {
+      tabOrderWidgets.append(focusWidget(m_form->cellWidget(2, ValueColumn2)));
+    } else if(*it_s == "amount") {
+      tabOrderWidgets.append(focusWidget(m_form->cellWidget(3, ValueColumn2)));
+    } else if(*it_s == "state") {
+      tabOrderWidgets.append(focusWidget(m_form->cellWidget(5, ValueColumn2)));
+    }
+    ++it_s;
   }
-  // date
-  tabOrderWidgets.append(focusWidget(m_form->cellWidget(2, ValueColumn2)));
-  // amount
-  tabOrderWidgets.append(focusWidget(m_form->cellWidget(3, ValueColumn2)));
-  // state
-  tabOrderWidgets.append(focusWidget(m_form->cellWidget(5, ValueColumn2)));
 }
 
 void StdTransaction::arrangeWidgetsInRegister(QMap<QString, QWidget*>& editWidgets)
@@ -1287,34 +1309,40 @@ void StdTransaction::arrangeWidgetsInRegister(QMap<QString, QWidget*>& editWidge
 
 void StdTransaction::tabOrderInRegister(QWidgetList& tabOrderWidgets) const
 {
+  QStringList taborder = QStringList::split(",", KMyMoneyGlobalSettings::stdTransactionRegisterTabOrder());
+  QStringList::const_iterator it_s = taborder.constBegin();
   QWidget* w;
-  // number
-  if(haveNumberField()) {
-    if((w = focusWidget(m_parent->cellWidget(m_startRow + 0, NumberColumn))))
-      tabOrderWidgets.append(w);
+  while(it_s != taborder.constEnd()) {
+    if(*it_s == "number") {
+      if(haveNumberField()) {
+        if((w = focusWidget(m_parent->cellWidget(m_startRow + 0, NumberColumn))))
+          tabOrderWidgets.append(w);
+      }
+    } else if(*it_s == "date") {
+      tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, DateColumn)));
+    } else if(*it_s == "payee") {
+      tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, DetailColumn)));
+    } else if(*it_s == "category") {
+      // make sure to have the category field and the split button as seperate tab order widgets
+      // ok, we have to have some internal knowledge about the KMyMoneyCategory object, but
+      // it's one of our own widgets, so we actually don't care. Just make sure, that we don't
+      // go haywire when someone changes the KMyMoneyCategory object ...
+      w = m_parent->cellWidget(m_startRow + 1, DetailColumn);
+      tabOrderWidgets.append(focusWidget(w));
+      w = dynamic_cast<QWidget*>(w->child("splitButton"));
+      if(w)
+        tabOrderWidgets.append(w);
+    } else if(*it_s == "memo") {
+      tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 2, DetailColumn)));
+    } else if(*it_s == "payment") {
+      tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, PaymentColumn)));
+    } else if(*it_s == "deposit") {
+      tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, DepositColumn)));
+    } else if(*it_s == "state") {
+      tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 1, DateColumn)));
+    }
+    ++it_s;
   }
-
-  // date
-  tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, DateColumn)));
-  // payee
-  tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, DetailColumn)));
-  // make sure to have the category field and the split button as seperate tab order widgets
-  // ok, we have to have some internal knowledge about the KMyMoneyCategory object, but
-  // it's one of our own widgets, so we actually don't care. Just make sure, that we don't
-  // go haywire when someone changes the KMyMoneyCategory object ...
-  w = m_parent->cellWidget(m_startRow + 1, DetailColumn);
-  tabOrderWidgets.append(focusWidget(w));
-  w = dynamic_cast<QWidget*>(w->child("splitButton"));
-  if(w)
-    tabOrderWidgets.append(w);
-  // memo
-  tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 2, DetailColumn)));
-  // payment
-  tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, PaymentColumn)));
-  // deposit
-  tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 0, DepositColumn)));
-  // status
-  tabOrderWidgets.append(focusWidget(m_parent->cellWidget(m_startRow + 1, DateColumn)));
 }
 
 int StdTransaction::numRowsRegister(bool expanded) const
@@ -1487,7 +1515,8 @@ bool InvestTransaction::formCellText(QString& txt, int& align, int row, int col,
         case ValueColumn1:
           align |= Qt::AlignLeft;
           fieldEditable = true;
-          txt = m_security.name();
+          if(m_account.isInvest())
+            txt = m_security.name();
           break;
 
         case LabelColumn2:
@@ -1565,7 +1594,7 @@ bool InvestTransaction::formCellText(QString& txt, int& align, int row, int col,
           align |= Qt::AlignRight;
           if(haveFees()) {
             if((fieldEditable = !m_feeCategory.isEmpty()) == true) {
-              txt = m_feeAmount.abs().formatMoney(m_account.fraction());
+              txt = m_feeAmount.abs().formatMoney(m_currency);
             }
           }
           break;
@@ -1597,7 +1626,7 @@ bool InvestTransaction::formCellText(QString& txt, int& align, int row, int col,
           align |= Qt::AlignRight;
           if(haveInterest()) {
             if((fieldEditable = !m_interestCategory.isEmpty()) == true) {
-              txt = m_interestAmount.abs().formatMoney(m_account.fraction());
+              txt = m_interestAmount.abs().formatMoney(m_currency);
             }
           }
           break;
@@ -1669,7 +1698,8 @@ void InvestTransaction::registerCellText(QString& txt, int& align, int row, int
 
         case SecurityColumn:
           align |= Qt::AlignLeft;
-          txt = m_security.name();
+          if(m_account.isInvest())
+            txt = m_security.name();
           break;
 
         case ReconcileFlagColumn:
@@ -1706,7 +1736,7 @@ void InvestTransaction::registerCellText(QString& txt, int& align, int row, int
         case BalanceColumn:
           align |= Qt::AlignRight;
           if(m_showBalance)
-            txt = m_balance;
+            txt = m_balance.formatMoney("", MyMoneyMoney::denomToPrec(m_security.smallestAccountFraction()));
           else
             txt = "----";
           break;
