@@ -57,6 +57,7 @@
 #include <kmymoney/kguiutils.h>
 
 #include "../../dialogs/ksplittransactiondlg.h"
+#include "../../dialogs/kequitypriceupdatedlg.h"
 #include "../../kmymoney2.h"
 
 using namespace NewAccountWizard;
@@ -194,7 +195,7 @@ MyMoneyTransaction NewAccountWizard::Wizard::payoutTransaction(void)
     s.setValue(-s.value());
     s.setAccountId(m_loanPayoutPage->payoutAccountId());
     MyMoneyMoney shares;
-    KCurrencyCalculator::setupSplitPrice(shares, t, s, QMap<QCString, MyMoneyMoney>(), this);
+    KCurrencyCalculator::setupSplitPrice(shares, t, s, QMap<QString, MyMoneyMoney>(), this);
     s.setShares(shares);
     t.addSplit(s);
   }
@@ -238,7 +239,8 @@ const MyMoneySchedule& NewAccountWizard::Wizard::schedule(void)
       m_schedule.setType(MyMoneySchedule::TYPE_TRANSFER);
       m_schedule.setPaymentType(static_cast<MyMoneySchedule::paymentTypeE>(m_schedulePage->m_method->currentItem()));
       m_schedule.setFixed(false);
-      m_schedule.setOccurence(MyMoneySchedule::OCCUR_MONTHLY);
+      m_schedule.setOccurencePeriod(MyMoneySchedule::OCCUR_MONTHLY);
+      m_schedule.setOccurenceMultiplier(1);
       MyMoneyTransaction t;
       MyMoneySplit s;
       s.setPayeeId(m_schedulePage->m_payee->selectedItem());
@@ -323,7 +325,7 @@ const MyMoneySchedule& NewAccountWizard::Wizard::schedule(void)
   return m_schedule;
 }
 
-MyMoneyMoney NewAccountWizard::Wizard::openingBalance(void)
+MyMoneyMoney NewAccountWizard::Wizard::openingBalance(void) const
 {
   // equity accounts don't have an opening balance
   if(m_accountTypePage->accountType() == MyMoneyAccount::Equity)
@@ -339,22 +341,36 @@ MyMoneyMoney NewAccountWizard::Wizard::openingBalance(void)
   return m_accountTypePage->m_openingBalance->value();
 }
 
+MyMoneyPrice NewAccountWizard::Wizard::conversionRate(void) const
+{
+  if(MyMoneyFile::instance()->baseCurrency().id() == m_accountTypePage->m_currencyComboBox->security().id())
+    return MyMoneyPrice(MyMoneyFile::instance()->baseCurrency().id(),
+                        m_accountTypePage->m_currencyComboBox->security().id(),
+                        m_accountTypePage->m_openingDate->date(),
+                        MyMoneyMoney(1,1),
+                        i18n("User"));
+  return MyMoneyPrice(MyMoneyFile::instance()->baseCurrency().id(),
+                      m_accountTypePage->m_currencyComboBox->security().id(),
+                      m_accountTypePage->m_openingDate->date(),
+                      m_accountTypePage->m_conversionRate->value(),
+                      i18n("User"));
+}
+
 bool NewAccountWizard::Wizard::moneyBorrowed(void) const
 {
   return m_generalLoanInfoPage->m_loanDirection->currentItem() == 0;
 }
 
-class NewAccountWizard::InstitutionPagePrivate
+class NewAccountWizard::InstitutionPage::Private
 {
 public:
-  InstitutionPagePrivate() {}
   QValueList<MyMoneyInstitution>  m_list;
 };
 
 InstitutionPage::InstitutionPage(Wizard* wizard, const char* name) :
   KInstitutionPageDecl(wizard),
   WizardPage<Wizard>(StepInstitution, this, wizard, name),
-  d(new InstitutionPagePrivate())
+  d(new Private())
 {
   connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), this, SLOT(slotLoadWidgets()));
   connect(m_newInstitutionButton, SIGNAL(clicked()), this, SLOT(slotNewInstitution()));
@@ -429,7 +445,8 @@ KMyMoneyWizardPage* InstitutionPage::nextPage(void) const
 
 AccountTypePage::AccountTypePage(Wizard* wizard, const char* name) :
   KAccountTypePageDecl(wizard),
-  WizardPage<Wizard>(StepAccount, this, wizard, name)
+  WizardPage<Wizard>(StepAccount, this, wizard, name),
+  m_showPriceWarning(true)
 {
   m_typeSelection->insertItem(i18n("Checking"), MyMoneyAccount::Checkings);
   m_typeSelection->insertItem(i18n("Savings"), MyMoneyAccount::Savings);
@@ -448,9 +465,18 @@ AccountTypePage::AccountTypePage(Wizard* wizard, const char* name) :
   m_currencyComboBox->setSecurity(MyMoneyFile::instance()->baseCurrency());
 
   m_mandatoryGroup->add(m_accountName);
+  m_mandatoryGroup->add(m_conversionRate->lineedit());
+
+  m_conversionRate->setPrecision(KMyMoneyGlobalSettings::pricePrecision());
+  m_conversionRate->setValue(MyMoneyMoney(1,1));
+  slotUpdateCurrency();
+
   connect(m_typeSelection, SIGNAL(itemSelected(int)), this, SLOT(slotUpdateType(int)));
   connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), this, SLOT(slotLoadWidgets()));
   connect(m_currencyComboBox, SIGNAL(activated(int)), this, SLOT(slotUpdateCurrency()));
+  connect(m_conversionRate, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateConversionRate(const QString&)));
+  connect(m_conversionRate, SIGNAL(valueChanged(const QString&)), this, SLOT(slotPriceWarning()));
+  connect(m_onlineQuote, SIGNAL(clicked()), this, SLOT(slotGetOnlineQuote()));
 }
 
 void AccountTypePage::slotUpdateType(int i)
@@ -491,20 +517,71 @@ void AccountTypePage::slotUpdateCurrency(void)
   MyMoneyAccount acc;
   acc.setAccountType(accountType());
 
-  m_openingBalance->setPrecision(MyMoneyMoney::denomToPrec(acc.fraction()));
+  m_openingBalance->setPrecision(MyMoneyMoney::denomToPrec(acc.fraction(currency())));
+
+  bool show =  m_currencyComboBox->security().id() != MyMoneyFile::instance()->baseCurrency().id();
+  m_conversionLabel->setShown(show);
+  m_conversionRate->setShown(show);
+  m_conversionExample->setShown(show);
+  m_onlineQuote->setShown(show);
+  m_conversionRate->setEnabled(show);       // make sure to include/exclude in mandatoryGroup
+  m_mandatoryGroup->changed();
+  slotUpdateConversionRate(m_conversionRate->lineedit()->text());
+}
+
+void AccountTypePage::slotGetOnlineQuote(void)
+{
+  QString id = MyMoneyFile::instance()->baseCurrency().id()+" "+m_currencyComboBox->security().id();
+  KEquityPriceUpdateDlg dlg(this, id);
+  if(dlg.exec() == QDialog::Accepted) {
+    MyMoneyPrice price = dlg.price(id);
+    if(price.isValid()) {
+      m_conversionRate->setValue(price.rate(m_currencyComboBox->security().id()));
+      if(price.date() != m_openingDate->date()) {
+        priceWarning(true);
+      }
+    }
+  }
+}
+
+void AccountTypePage::slotPriceWarning(void)
+{
+  priceWarning(false);
+}
+
+void AccountTypePage::priceWarning(bool always)
+{
+  if(m_showPriceWarning || always) {
+    KMessageBox::information(this, i18n("Please make sure to enter the correct conversion for the selected opening date. If you requested an online quote it might be provided for a different date."), i18n("Check date"));
+  }
+  m_showPriceWarning = false;
+}
+
+void AccountTypePage::slotUpdateConversionRate(const QString& txt)
+{
+  m_conversionExample->setText(i18n("1 %1 equals %2").
+      arg(MyMoneyFile::instance()->baseCurrency().tradingSymbol()).
+      arg(MyMoneyMoney(txt).formatMoney(m_currencyComboBox->security().tradingSymbol(), KMyMoneyGlobalSettings::pricePrecision())));
 }
 
 void AccountTypePage::slotLoadWidgets(void)
 {
-  m_currencyComboBox->update(QCString("x"));
+  m_currencyComboBox->update(QString("x"));
 }
 
 bool AccountTypePage::isComplete(void) const
 {
-  bool rc = KMyMoneyWizardPage::isComplete();
-
+  // check that the conversion rate is positive if enabled
+  bool rc = !m_conversionRate->isVisible() || (!m_conversionRate->value().isZero() && !m_conversionRate->value().isNegative());
   if(!rc) {
-    QToolTip::add(m_wizard->m_nextButton, i18n("No account name supplied"));
+    QToolTip::add(m_wizard->m_nextButton, i18n("Conversion rate is not positive"));
+
+  } else {
+    rc = KMyMoneyWizardPage::isComplete();
+
+    if(!rc) {
+      QToolTip::add(m_wizard->m_nextButton, i18n("No account name supplied"));
+    }
   }
   hideShowPages(accountType());
   return rc;
@@ -557,7 +634,7 @@ BrokeragePage::BrokeragePage(Wizard* wizard, const char* name) :
 
 void BrokeragePage::slotLoadWidgets(void)
 {
-  m_brokerageCurrency->update(QCString("x"));
+  m_brokerageCurrency->update(QString("x"));
 }
 
 void BrokeragePage::enterPage(void)
@@ -589,11 +666,11 @@ CreditCardSchedulePage::CreditCardSchedulePage(Wizard* wizard, const char* name)
   m_mandatoryGroup->add(m_payee);
   m_mandatoryGroup->add(m_amount->lineedit());
   m_mandatoryGroup->add(m_paymentAccount);
-  connect(m_paymentAccount, SIGNAL(itemSelected(const QCString&)), object(), SIGNAL(completeStateChanged()));
-  connect(m_payee, SIGNAL(itemSelected(const QCString&)), object(), SIGNAL(completeStateChanged()));
+  connect(m_paymentAccount, SIGNAL(itemSelected(const QString&)), object(), SIGNAL(completeStateChanged()));
+  connect(m_payee, SIGNAL(itemSelected(const QString&)), object(), SIGNAL(completeStateChanged()));
   connect(m_date, SIGNAL(dateChanged(const QDate&)), object(), SIGNAL(completeStateChanged()));
 
-  connect(m_payee, SIGNAL(createItem(const QString&, QCString&)), wizard, SIGNAL(createPayee(const QString&, QCString&)));
+  connect(m_payee, SIGNAL(createItem(const QString&, QString&)), wizard, SIGNAL(createPayee(const QString&, QString&)));
 
   m_reminderCheckBox->setChecked(true);
   connect(m_reminderCheckBox, SIGNAL(toggled(bool)), object(), SIGNAL(completeStateChanged()));
@@ -683,7 +760,7 @@ GeneralLoanInfoPage::GeneralLoanInfoPage(Wizard* wizard, const char* name) :
 
   slotLoadWidgets();
 
-  connect(m_payee, SIGNAL(createItem(const QString&, QCString&)), wizard, SIGNAL(createPayee(const QString&, QCString&)));
+  connect(m_payee, SIGNAL(createItem(const QString&, QString&)), wizard, SIGNAL(createPayee(const QString&, QString&)));
   connect(m_anyPayments, SIGNAL(activated(int)), object(),  SIGNAL(completeStateChanged()));
   connect(m_recordings, SIGNAL(activated(int)), object(), SIGNAL(completeStateChanged()));
 
@@ -770,6 +847,8 @@ LoanDetailsPage::LoanDetailsPage(Wizard* wizard, const char* name) :
 {
   // force the balloon payment to zero (default)
   m_balloonAmount->setValue(MyMoneyMoney());
+  // allow any precision for the interest rate
+  m_interestRate->setPrecision(-1);
 
   connect(m_paymentDue, SIGNAL(activated(int)), this, SLOT(slotValuesChanged()));
 
@@ -1128,7 +1207,7 @@ KMyMoneyWizardPage* LoanDetailsPage::nextPage(void) const
 }
 
 
-class NewAccountWizard::LoanPaymentPagePrivate
+class NewAccountWizard::LoanPaymentPage::Private
 {
 public:
   MyMoneyAccount      phonyAccount;
@@ -1140,9 +1219,9 @@ public:
 LoanPaymentPage::LoanPaymentPage(Wizard* wizard, const char* name) :
   KLoanPaymentPageDecl(wizard),
   WizardPage<Wizard>(StepFees, this, wizard, name),
-  d(new LoanPaymentPagePrivate)
+  d(new Private)
 {
-  d->phonyAccount = MyMoneyAccount(QCString("Phony-ID"), MyMoneyAccount());
+  d->phonyAccount = MyMoneyAccount(QString("Phony-ID"), MyMoneyAccount());
 
   d->phonySplit.setAccountId(d->phonyAccount.id());
   d->phonySplit.setValue(0);
@@ -1199,7 +1278,7 @@ void LoanPaymentPage::enterPage(void)
 
 void LoanPaymentPage::slotAdditionalFees(void)
 {
-  QMap<QCString, MyMoneyMoney> priceInfo;
+  QMap<QString, MyMoneyMoney> priceInfo;
   KSplitTransactionDlg* dlg = new KSplitTransactionDlg(d->additionalFeesTransaction, d->phonySplit, d->phonyAccount, false, !m_wizard->moneyBorrowed(), MyMoneyMoney(0), priceInfo);
 
   // connect(dlg, SIGNAL(newCategory(MyMoneyAccount&)), this, SIGNAL(newCategory(MyMoneyAccount&)));
@@ -1233,11 +1312,11 @@ LoanSchedulePage::LoanSchedulePage(Wizard* wizard, const char* name) :
 {
   m_mandatoryGroup->add(m_interestCategory->lineEdit());
   m_mandatoryGroup->add(m_paymentAccount->lineEdit());
-  connect(m_interestCategory, SIGNAL(createItem(const QString&, QCString&)), this, SLOT(slotCreateCategory(const QString&, QCString&)));
+  connect(m_interestCategory, SIGNAL(createItem(const QString&, QString&)), this, SLOT(slotCreateCategory(const QString&, QString&)));
   connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), this, SLOT(slotLoadWidgets()));
 }
 
-void LoanSchedulePage::slotCreateCategory(const QString& name, QCString& id)
+void LoanSchedulePage::slotCreateCategory(const QString& name, QString& id)
 {
   MyMoneyAccount acc, parent;
   acc.setName(name);
@@ -1369,7 +1448,7 @@ bool LoanPayoutPage::isComplete(void) const
   return KMyMoneyWizardPage::isComplete() | m_noPayoutTransaction->isChecked();
 }
 
-const QCString& LoanPayoutPage::payoutAccountId(void) const
+const QString& LoanPayoutPage::payoutAccountId(void) const
 {
   if(m_refinanceLoan->isChecked()) {
     return m_loanAccount->selectedItem();
@@ -1382,7 +1461,11 @@ HierarchyPage::HierarchyPage(Wizard* wizard, const char* name) :
   KHierarchyPageDecl(wizard),
   WizardPage<Wizard>(StepParentAccount, this, wizard, name)
 {
-  m_mandatoryGroup->add(m_qlistviewParentAccounts);
+  // the next line causes a warning to be shown in the console output
+  // since at least one of the major groups is selected, and the user
+  // cannot deselect an account, at least one is selected all the time
+  // and we don't need this check
+  // m_mandatoryGroup->add(m_qlistviewParentAccounts);
   m_qlistviewParentAccounts->setEnabled(true);
   m_qlistviewParentAccounts->setRootIsDecorated(true);
   m_qlistviewParentAccounts->setAllColumnsShowFocus(true);
@@ -1431,7 +1514,7 @@ KMyMoneyAccountTreeItem* HierarchyPage::buildAccountTree
   KMyMoneyAccountTreeItem* childItem = new KMyMoneyAccountTreeItem( parent, account );
   if ( open )
     childItem->setOpen(true);
-  for ( QCStringList::ConstIterator it = account.accountList().begin();
+  for ( QStringList::ConstIterator it = account.accountList().begin();
         it != account.accountList().end();
         ++it )
   {
@@ -1456,7 +1539,7 @@ KMyMoneyAccountTreeItem* HierarchyPage::buildAccountTree
   KMyMoneyAccountTreeItem* childItem = new KMyMoneyAccountTreeItem( parent, account );
   if ( open )
     childItem->setOpen(true);
-  for ( QCStringList::ConstIterator it = account.accountList().begin();
+  for ( QStringList::ConstIterator it = account.accountList().begin();
         it != account.accountList().end();
         ++it )
   {
@@ -1498,9 +1581,11 @@ void AccountSummaryPage::enterPage(void)
 {
   MyMoneyAccount acc = m_wizard->account();
   MyMoneySecurity sec = m_wizard->currency();
+  acc.fraction(sec);
+
   // assign an id to the account inside the wizard which is required for a schedule
   // get the schedule and clear the id again in the wizards object.
-  MyMoneyAccount tmp(QCString("Phony-ID"), acc);
+  MyMoneyAccount tmp(QString("Phony-ID"), acc);
   m_wizard->setAccount(tmp);
   MyMoneySchedule sch = m_wizard->schedule();
   m_wizard->setAccount(acc);
@@ -1508,7 +1593,7 @@ void AccountSummaryPage::enterPage(void)
   m_dataList->clear();
 
   // Account data
-  QListViewItem* group = new KMyMoneyCheckListItem(m_dataList, i18n("Account information"), QString(), QCString(), QCheckListItem::RadioButtonController);
+  QListViewItem* group = new KMyMoneyCheckListItem(m_dataList, i18n("Account information"), QString(), QString(), QCheckListItem::RadioButtonController);
   group->setOpen(true);
   QListViewItem* p;
   p = new KListViewItem(group, i18n("Name"), acc.name());
@@ -1521,6 +1606,9 @@ void AccountSummaryPage::enterPage(void)
     p = new KListViewItem(group, p, i18n("Type"), m_wizard->m_accountTypePage->m_typeSelection->currentText());
   p = new KListViewItem(group, p, i18n("Currency"), m_wizard->currency().name());
   p = new KListViewItem(group, p, i18n("Opening date"), KGlobal::locale()->formatDate(acc.openingDate()));
+  if(m_wizard->currency().id() != MyMoneyFile::instance()->baseCurrency().id()) {
+    p = new KListViewItem(group, p, i18n("Conversion rate"), m_wizard->conversionRate().rate(QString()).formatMoney("", KMyMoneyGlobalSettings::pricePrecision()));
+  }
   if(!acc.isLoan() || !m_wizard->openingBalance().isZero())
     p = new KListViewItem(group, p, i18n("Opening balance"), m_wizard->openingBalance().formatMoney(acc, sec));
 
@@ -1536,7 +1624,7 @@ void AccountSummaryPage::enterPage(void)
 
   if(acc.accountType() == MyMoneyAccount::Investment) {
     if(m_wizard->m_brokeragepage->m_createBrokerageButton->isChecked()) {
-      group = new KMyMoneyCheckListItem(m_dataList, group, i18n("Brokerage Account"), QString(), QCString(), QCheckListItem::RadioButtonController);
+      group = new KMyMoneyCheckListItem(m_dataList, group, i18n("Brokerage Account"), QString(), QString(), QCheckListItem::RadioButtonController);
       group->setOpen(true);
       p = new KListViewItem(group, p, i18n("Name"), QString("%1 (Brokerage)").arg(acc.name()));
       p = new KListViewItem(group, p, i18n("Currency"), m_wizard->m_brokeragepage->m_brokerageCurrency->security().name());
@@ -1549,14 +1637,14 @@ void AccountSummaryPage::enterPage(void)
 
   // Loan
   if(acc.isLoan()) {
-    group = new KMyMoneyCheckListItem(m_dataList, group, i18n("Loan information"), QString(), QCString(), QCheckListItem::RadioButtonController);
+    group = new KMyMoneyCheckListItem(m_dataList, group, i18n("Loan information"), QString(), QString(), QCheckListItem::RadioButtonController);
     group->setOpen(true);
     if(m_wizard->moneyBorrowed()) {
       p = new KListViewItem(group, p, i18n("Amount borrowed"), m_wizard->m_loanDetailsPage->m_loanAmount->value().formatMoney(m_wizard->currency().tradingSymbol(), m_wizard->precision()));
     } else {
       p = new KListViewItem(group, p, i18n("Amount lent"), m_wizard->m_loanDetailsPage->m_loanAmount->value().formatMoney(m_wizard->currency().tradingSymbol(), m_wizard->precision()));
     }
-    p = new KListViewItem(group, p, i18n("Interest rate"), QString("%1 %").arg(m_wizard->m_loanDetailsPage->m_interestRate->value().formatMoney("", 3)));
+    p = new KListViewItem(group, p, i18n("Interest rate"), QString("%1 %").arg(m_wizard->m_loanDetailsPage->m_interestRate->value().formatMoney("", -1)));
     p = new KListViewItem(group, p, i18n("Interest rate is"), m_wizard->m_generalLoanInfoPage->m_interestType->currentText());
     p = new KListViewItem(group, p, i18n("Principal and interest"), m_wizard->m_loanDetailsPage->m_paymentAmount->value().formatMoney(acc, sec));
     p = new KListViewItem(group, p, i18n("Additional fees"), m_wizard->m_loanPaymentPage->additionalFees().formatMoney(acc, sec));
@@ -1564,7 +1652,7 @@ void AccountSummaryPage::enterPage(void)
     p = new KListViewItem(group, p, i18n("Payment account"), m_wizard->m_loanSchedulePage->m_paymentAccount->currentText());
 
     if(!m_wizard->m_loanPayoutPage->m_noPayoutTransaction->isChecked() && m_wizard->openingBalance().isZero()) {
-      group = new KMyMoneyCheckListItem(m_dataList, group, i18n("Payout information"), QString(), QCString(), QCheckListItem::RadioButtonController);
+      group = new KMyMoneyCheckListItem(m_dataList, group, i18n("Payout information"), QString(), QString(), QCheckListItem::RadioButtonController);
       group->setOpen(true);
       if(m_wizard->m_loanPayoutPage->m_refinanceLoan->isChecked()) {
         p = new KListViewItem(group, p, i18n("Refinance"), m_wizard->m_loanPayoutPage->m_loanAccount->currentText());
@@ -1580,7 +1668,7 @@ void AccountSummaryPage::enterPage(void)
 
   // Schedule
   if(!(sch == MyMoneySchedule())) {
-    group = new KMyMoneyCheckListItem(m_dataList, group, i18n("Schedule information"), QString(), QCString(), QCheckListItem::RadioButtonController);
+    group = new KMyMoneyCheckListItem(m_dataList, group, i18n("Schedule information"), QString(), QString(), QCheckListItem::RadioButtonController);
     group->setOpen(true);
     p = new KListViewItem(group, i18n("Name"), sch.name());
     if(acc.accountType() == MyMoneyAccount::CreditCard) {
